@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -50,16 +50,15 @@
 #include "MsXpS/libXpertMassCore/Utils.hpp"
 #include "MsXpS/libXpertMassCore/Formula.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
 {
 
-  /*  BEGIN CLASS JS REFERENCE
-   *  namespace: MsXpS::libXpertMassCore
-   *  class name: Ionizer
-   */
+/*  BEGIN CLASS JS REFERENCE
+ *  namespace: MsXpS::libXpertMassCore
+ *  class name: Ionizer
+ */
 
 class DECLSPEC Ionizer: public QObject
 {
@@ -88,11 +87,13 @@ class DECLSPEC Ionizer: public QObject
   Ionizer(IsotopicDataCstSPtr isotopic_data_csp,
           const Formula &formula,
           int charge,
-          int level, QObject *parent = nullptr);
+          int level,
+          QObject *parent = nullptr);
   Ionizer(IsotopicDataCstSPtr isotopic_data_csp,
           const QString &formula_string,
           int charge,
-          int level, QObject *parent = nullptr);
+          int level,
+          QObject *parent = nullptr);
 
   // Pseudo copy constructor
   Ionizer(const Ionizer &other, QObject *parent = nullptr);
@@ -167,16 +168,15 @@ typedef std::shared_ptr<Ionizer> IonizerSPtr;
 typedef std::shared_ptr<const Ionizer> IonizerCstSPtr;
 
 
-  /*  END CLASS JS REFERENCE
-   *  namespace: MsXpS::libXpertMassCore
-   *  class name: Ionizer
-   */
+/*  END CLASS JS REFERENCE
+ *  namespace: MsXpS::libXpertMassCore
+ *  class name: Ionizer
+ */
 
 } // namespace libXpertMassCore
 MSXPS_REGISTER_JS_CLASS(MsXpS::libXpertMassCore, Ionizer)
 } // namespace MsXpS
 
-
 Q_DECLARE_METATYPE(MsXpS::libXpertMassCore::Ionizer);
 extern int ionizerMetaTypeId;
 
