@@ -77,14 +77,14 @@ class DECLSPEC IsotopicClusterGenerator
 
   public:
   IsotopicClusterGenerator();
-  IsotopicClusterGenerator(libXpertMassCore::IsotopicDataSPtr isotopic_data_sp);
+  IsotopicClusterGenerator(IsotopicDataSPtr isotopic_data_sp);
 
   virtual ~IsotopicClusterGenerator();
 
   void setIsotopicDataType(IsotopicDataType isotopic_data_type);
 
-  void setIsotopicData(libXpertMassCore::IsotopicDataSPtr isotopic_data_sp);
-  libXpertMassCore::IsotopicDataSPtr getIsotopicData() const;
+  void setIsotopicData(IsotopicDataSPtr isotopic_data_sp);
+  IsotopicDataSPtr getIsotopicData() const;
 
   void setFormulaChargePairs(
     const std::vector<FormulaChargePair> &formula_charge_pairs);
@@ -128,7 +128,7 @@ class DECLSPEC IsotopicClusterGenerator
 
   protected:
   // Basic configuration
-  libXpertMassCore::IsotopicDataSPtr msp_isotopicData = nullptr;
+  IsotopicDataSPtr msp_isotopicData   = nullptr;
   IsotopicDataType m_isotopicDataType = IsotopicDataType::NOT_SET;
 
   double m_maxSummedProbability = 0.95;
