@@ -54,7 +54,6 @@
 #include "MsXpS/libXpertMassCore/Isotope.hpp"
 #include "MsXpS/libXpertMassCore/globals.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -84,17 +83,19 @@ class DECLSPEC IsotopicData: public QObject
   public:
   Q_INVOKABLE IsotopicData(QObject *parent = nullptr);
   // Pseudo copy constructor
-  Q_INVOKABLE IsotopicData(const IsotopicData &other, QObject *parent = nullptr);
+  Q_INVOKABLE IsotopicData(const IsotopicData &other,
+                           QObject *parent = nullptr);
 
   virtual ~IsotopicData();
 
-  Q_INVOKABLE void appendNewIsotope(IsotopeQSPtr isotope_qsp, bool update_maps = true);
+  Q_INVOKABLE void appendNewIsotope(IsotopeQSPtr isotope_qsp,
+                                    bool update_maps = true);
   Q_INVOKABLE bool insertNewIsotope(IsotopeQSPtr isotope_qsp,
-                        qsizetype index,
-                        bool update_maps = true);
+                                    qsizetype index,
+                                    bool update_maps = true);
 
   Q_INVOKABLE void appendNewIsotopes(const QList<IsotopeQSPtr> &isotopes,
-                         bool update_maps = true);
+                                     bool update_maps = true);
 
   IsotopeListCstIterator eraseIsotopes(qsizetype begin_index,
                                        qsizetype end_index,
@@ -112,7 +113,7 @@ class DECLSPEC IsotopicData: public QObject
   Q_INVOKABLE std::size_t updateAvgMassMap();
 
   Q_INVOKABLE double computeAvgMass(IsotopeListCstIteratorPair iter_pair,
-                        ErrorList *error_list_p) const;
+                                    ErrorList *error_list_p) const;
 
   Q_INVOKABLE void updateMassMaps(const QString &symbol);
   Q_INVOKABLE std::size_t updateMassMaps();
@@ -124,15 +125,17 @@ class DECLSPEC IsotopicData: public QObject
   // Get the monoisotopic mass of carbon.
   Q_INVOKABLE double getMonoMassBySymbol(const QString &symbol, bool &ok) const;
   Q_INVOKABLE double getMonoMass(IsotopeListCstIteratorPair iter_pair,
-                     ErrorList *error_list_p) const;
+                                 ErrorList *error_list_p) const;
 
   Q_INVOKABLE double getAvgMassBySymbol(const QString &symbol, bool &ok) const;
 
-  Q_INVOKABLE double getCumulatedProbabilitiesBySymbol(const QString &symbol,
-                                           ErrorList *error_list_p) const;
+  Q_INVOKABLE double
+  getCumulatedProbabilitiesBySymbol(const QString &symbol,
+                                    ErrorList *error_list_p) const;
 
-  Q_INVOKABLE double getCumulatedProbabilities(IsotopeListCstIteratorPair iter_pair,
-                                   ErrorList *error_list_p) const;
+  Q_INVOKABLE double
+  getCumulatedProbabilities(IsotopeListCstIteratorPair iter_pair,
+                            ErrorList *error_list_p) const;
 
   IsotopeListCstIteratorPair getIsotopesBySymbol(const QString &symbol) const;
 
@@ -202,4 +205,3 @@ typedef std::shared_ptr<const IsotopicData> IsotopicDataCstSPtr;
 } // namespace libXpertMassCore
 MSXPS_REGISTER_JS_CLASS(MsXpS::libXpertMassCore, IsotopicData)
 } // namespace MsXpS
-
