@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -45,8 +45,6 @@ int calcOptionsMetaTypeId =
   qRegisterMetaType<MsXpS::libXpertMassCore::CalcOptions>(
     "MsXpS::libXpertMassCore::CalcOptions");
 
-
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -206,7 +204,8 @@ CalcOptions::CalcOptions(const CalcOptions &other, QObject *parent)
 }
 
 /*!
-\brief Returns a reference to this CalcOptions after having initialized it using \a other.
+\brief Returns a reference to this CalcOptions after having initialized it using
+\a other.
 */
 CalcOptions &
 CalcOptions::initialize(const CalcOptions &other)
@@ -228,7 +227,8 @@ CalcOptions::initialize(const CalcOptions &other)
 }
 
 /*!
-\brief Returns an newly allocated CalcOptions instance with parent set to \a parent.
+\brief Returns an newly allocated CalcOptions instance with parent set to \a
+parent.
 */
 CalcOptions *
 CalcOptions::clone(QObject *parent)
@@ -239,7 +239,8 @@ CalcOptions::clone(QObject *parent)
 }
 
 /*!
- \ b*rief Returns an newly allocated CalcOptions instance initialized using \a other and with parent set to \a parent.
+ \ b*rief Returns an newly allocated CalcOptions instance initialized using \a
+ other and with parent set to \a parent.
  */
 CalcOptions *
 CalcOptions::clone(const CalcOptions &other, QObject *parent)
@@ -537,7 +538,7 @@ CalcOptions::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register CalcOptions class: engine is null";
+      qDebug() << "Cannot register CalcOptions class: engine is null";
       return;
     }
 
