@@ -183,7 +183,7 @@ ChemicalGroup::ChemicalGroup(const QString &name,
     m_polymerizationRule(polymerization_rule)
 {
   if(m_pka <= 0 && m_pka >= 14)
-    qFatalStream() << "Programming error. pKa cannot be <=0 or >= 14.";
+    qFatal() << "Programming error. pKa cannot be <=0 or >= 14.";
 
   ErrorList error_list;
   m_isValid = validate(&error_list);
