@@ -202,7 +202,7 @@ CleavageAgent::CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
              "for construction of CleavageAgent instance.";
     }
   else
-    qFatalStream()
+    qFatal()
       << "Programming error. The polymer chemistry definition version "
          "is not correct.";
 }
