@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -35,7 +35,6 @@
 #include "MsXpS/libXpertMassCore/CleavageRule.hpp"
 #include "MsXpS/libXpertMassCore/PolChemDef.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -112,6 +111,17 @@ using a CleavageRule.
 */
 
 
+/*!
+\brief Constructs a CleavageRule instance with \a pol_chem_def_csp as the
+polymer chemistry definition.
+
+The validiy status (m_isValid) of this install will be set to false.
+*/
+CleavageRule::CleavageRule(PolChemDefCstSPtr pol_chem_def_csp)
+  : mcsp_polChemDef(pol_chem_def_csp)
+{
+}
+
 /*!
 \brief Constructs a CleavageRule instance
 
@@ -144,9 +154,9 @@ CleavageRule::CleavageRule(PolChemDefCstSPtr pol_chem_def_csp,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon construction of CleavageRule,  the instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon construction of CleavageRule,  the instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -167,7 +177,7 @@ CleavageRule::CleavageRule(const CleavageRule &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon copy-construction of CleavageRule,  the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -195,7 +205,7 @@ CleavageRule::setPolchemDefCstSPtr(PolChemDefCstSPtr pol_chem_def_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting PolChemDef of CleavageRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -225,9 +235,9 @@ CleavageRule::setName(const QString &name)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon setting name of CleavageRule, the instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon setting name of CleavageRule, the instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -254,7 +264,7 @@ CleavageRule::setLeftCode(const QString &code)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting left code of CleavageRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -284,7 +294,7 @@ CleavageRule::setRightCode(const QString &code)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting right code of CleavageRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -314,7 +324,7 @@ CleavageRule::setLeftFormula(const Formula &formula)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting left formula of CleavageRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -344,7 +354,7 @@ CleavageRule::setRightFormula(const Formula &formula)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting right formula of CleavageRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -359,7 +369,6 @@ CleavageRule::getRightFormula() const
   return m_rightFormula;
 }
 
-
 //////////////// OPERATORS /////////////////////
 /*!
 \brief Assigns to \a other to this CleavageRule instance.
@@ -388,9 +397,9 @@ CleavageRule::operator=(const CleavageRule &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon assignment of CleavageRule, the instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon assignment of CleavageRule, the instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 
   return *this;
 }
@@ -453,36 +462,45 @@ Returns m_isValid.
 bool
 CleavageRule::validate(ErrorList *error_list_p) const
 {
-  m_isValid = false;
-
-  qsizetype error_count = error_list_p->size();
+  m_isValid = true;
 
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
     {
-      qCritical() << "A CleavageRule with no PolChemDef available cannot "
-                     "validate successfully.";
-      error_list_p->push_back(
-        "A CleavageRule with no PolChemDef available cannot validate "
-        "successfully");
+      qDebug() << "A CleavageRule with no PolChemDef available cannot "
+                  "validate successfully.";
+
+      m_isValid = false;
+
+      if(error_list_p)
+        error_list_p->push_back(
+          "A CleavageRule with no PolChemDef available cannot validate "
+          "successfully");
     }
 
   if(m_name.isEmpty())
     {
-      qCritical()
-        << "A CleavageRule with no name cannot validate successfully.";
-      error_list_p->push_back(
-        "A CleavageRule with no name cannot validate successfully");
+      qDebug() << "A CleavageRule with no name cannot validate successfully.";
+
+      m_isValid = false;
+
+      if(error_list_p)
+        error_list_p->push_back(
+          "A CleavageRule with no name cannot validate successfully");
     }
 
   if(m_leftCode.isEmpty() && !m_leftFormula.getActionFormula().isEmpty())
     {
-      qCritical()
+      qDebug()
         << "A CleavageRule without a left monomer code but with a left formula"
            "cannot validate successfully.";
-      error_list_p->push_back(
-        "A CleavageRule without a left monomer code but with a left formula "
-        "cannot validate "
-        "successfully");
+
+      m_isValid = false;
+
+      if(error_list_p)
+        error_list_p->push_back(
+          "A CleavageRule without a left monomer code but with a left formula "
+          "cannot validate "
+          "successfully");
     }
 
   if(!m_leftCode.isEmpty())
@@ -490,42 +508,60 @@ CleavageRule::validate(ErrorList *error_list_p) const
       if(mcsp_polChemDef != nullptr && mcsp_polChemDef.get() != nullptr &&
          mcsp_polChemDef->getMonomerCstSPtrByCode(m_leftCode) == nullptr)
         {
-          qCritical() << "A CleavageRule with an unknown left monomer code "
-                         "cannot validate successfully.";
-          error_list_p->push_back(
-            "A CleavageRule with an unknown left monomer code cannot validate "
-            "successfully");
+          qDebug() << "A CleavageRule with an unknown left monomer code "
+                      "cannot validate successfully.";
+
+          m_isValid = false;
+
+          if(error_list_p)
+            error_list_p->push_back(
+              "A CleavageRule with an unknown left monomer code cannot "
+              "validate "
+              "successfully");
         }
 
       if(m_leftFormula.getActionFormula().isEmpty())
         {
-          qCritical() << "A CleavageRule with an empty left formula cannot "
-                         "validate successfully.";
-          error_list_p->push_back(
-            "A CleavageRule with an empty left formula cannot validate "
-            "successfully");
+          qDebug() << "A CleavageRule with an empty left formula cannot "
+                      "validate successfully.";
+
+          m_isValid = false;
+
+          if(error_list_p)
+            error_list_p->push_back(
+              "A CleavageRule with an empty left formula cannot validate "
+              "successfully");
         }
       else if(mcsp_polChemDef != nullptr && mcsp_polChemDef.get() != nullptr &&
               !m_leftFormula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(),
                                       error_list_p))
         {
-          qCritical() << "A CleavageRule with an invalid left formula cannot "
-                         "validate successfully.";
-          error_list_p->push_back(
-            "A CleavageRule with an invalid left formula cannot validate "
-            "successfully");
+          qDebug() << "A CleavageRule with an invalid left formula cannot "
+                      "validate successfully.";
+
+          m_isValid = false;
+
+          if(error_list_p)
+            error_list_p->push_back(
+              "A CleavageRule with an invalid left formula cannot validate "
+              "successfully");
         }
     }
 
   if(m_rightCode.isEmpty() && !m_rightFormula.getActionFormula().isEmpty())
     {
-      qCritical() << "A CleavageRule without a right monomer code but with a "
-                     "right formula"
-                     "cannot validate successfully.";
-      error_list_p->push_back(
-        "A CleavageRule without a right monomer code but with a right formula "
-        "cannot validate "
-        "successfully");
+      qDebug() << "A CleavageRule without a right monomer code but with a "
+                  "right formula"
+                  "cannot validate successfully.";
+
+      m_isValid = false;
+
+      if(error_list_p)
+        error_list_p->push_back(
+          "A CleavageRule without a right monomer code but with a right "
+          "formula "
+          "cannot validate "
+          "successfully");
     }
 
   if(!m_rightCode.isEmpty())
@@ -533,35 +569,46 @@ CleavageRule::validate(ErrorList *error_list_p) const
       if(mcsp_polChemDef != nullptr && mcsp_polChemDef.get() != nullptr &&
          mcsp_polChemDef->getMonomerCstSPtrByCode(m_rightCode) == nullptr)
         {
-          qCritical() << "A CleavageRule with an unknown right monomer code "
-                         "cannot validate successfully.";
-          error_list_p->push_back(
-            "A CleavageRule with an unknown right monomer code cannot validate "
-            "successfully");
+          qDebug() << "A CleavageRule with an unknown right monomer code "
+                      "cannot validate successfully.";
+
+          m_isValid = false;
+
+          if(error_list_p)
+            error_list_p->push_back(
+              "A CleavageRule with an unknown right monomer code cannot "
+              "validate "
+              "successfully");
         }
 
       if(m_rightFormula.getActionFormula().isEmpty())
         {
-          qCritical() << "A CleavageRule with an empty right formula cannot "
-                         "validate successfully.";
-          error_list_p->push_back(
-            "A CleavageRule with an empty right formula cannot validate "
-            "successfully");
+          qDebug() << "A CleavageRule with an empty right formula cannot "
+                      "validate successfully.";
+
+          m_isValid = false;
+
+          if(error_list_p)
+            error_list_p->push_back(
+              "A CleavageRule with an empty right formula cannot validate "
+              "successfully");
         }
       else if(mcsp_polChemDef != nullptr && mcsp_polChemDef.get() != nullptr &&
               !m_rightFormula.validate(
                 mcsp_polChemDef->getIsotopicDataCstSPtr(), error_list_p))
         {
-          qCritical() << "A CleavageRule with an invalid right formula cannot "
-                         "validate successfully.";
-          error_list_p->push_back(
-            "A CleavageRule with an invalid right formula cannot validate "
-            "successfully");
+          qDebug() << "A CleavageRule with an invalid right formula cannot "
+                      "validate successfully.";
+
+          m_isValid = false;
+
+          if(error_list_p)
+            error_list_p->push_back(
+              "A CleavageRule with an invalid right formula cannot validate "
+              "successfully");
         }
     }
 
-  m_isValid = error_list_p->size() > error_count ? false : true;
-
   return m_isValid;
 }
 
@@ -694,7 +741,7 @@ CleavageRule::renderXmlClrElement(const QDomElement &element,
   m_isValid = validate(&error_list);
   if(!m_isValid)
     {
-      qCritical() << "The CleavageRule rendered from <clr> element is invalid.";
+      qDebug() << "The CleavageRule rendered from <clr> element is invalid.";
     }
 
   qDebug() << "The <clr> element was rendered successfully.";
