@@ -148,10 +148,10 @@ Cleaver::Cleaver(PolymerCstQSPtr polymer_cqsp,
     m_ionizer(ionizer)
 {
   if(mcsp_polymer == nullptr && mcsp_polymer.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   if(mcsp_polChemDef == nullptr && mcsp_polChemDef.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   m_calcOptions.initialize(calc_options);
 
@@ -175,10 +175,10 @@ Cleaver::Cleaver(const Cleaver &other)
     m_ionizer(other.m_ionizer)
 {
   if(mcsp_polymer == nullptr && mcsp_polymer.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   if(mcsp_polChemDef == nullptr && mcsp_polChemDef.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   m_calcOptions.initialize(other.m_calcOptions);
 
@@ -229,7 +229,7 @@ Cleaver::transferOligomers(OligomerCollection &source, OligomerCollection &dest)
 
   // Sanity check
   if(transferred_count != source.getOligomersRef().size())
-    qFatalStream()
+    qFatal()
       << "Programming error. Not all the Oligomers were transferred.";
 
   // Now clear the source container which contains the same items as before but
@@ -445,7 +445,7 @@ Cleaver::fillCleavageIndices()
               //   << "Not for cleavage";
             }
           else
-            qFatalStream()
+            qFatal()
               << "Programming error. Enums::CleavageAction::NOT_SET is not "
                  "possible here.";
         }
@@ -592,7 +592,7 @@ Cleaver::findCleavageMotif(CleavageMotif &cleavage_motif,
     {
       MonomerSPtr monomer_sp = polymer_sequence_monomers.at(iter_index);
       if(monomer_sp == nullptr)
-        qFatalStream() << "Programming error.";
+        qFatal() << "Programming error.";
 
       if(monomer_sp->getCode() != first_code)
         {
@@ -627,7 +627,7 @@ Cleaver::findCleavageMotif(CleavageMotif &cleavage_motif,
           monomer_sp        = polymer_sequence_monomers.at(iter_index + iter);
 
           if(monomer_sp == nullptr)
-            qFatalStream() << "Programming error.";
+            qFatal() << "Programming error.";
 
           if(monomer_sp->getCode() == next_code)
             continue;
@@ -670,10 +670,10 @@ Cleaver::accountCleavageRule(CleavageRuleSPtr cleavage_rule_sp,
                              OligomerSPtr oligomer_sp)
 {
   if(cleavage_rule_sp == nullptr || cleavage_rule_sp.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   if(oligomer_sp == nullptr || oligomer_sp.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   IsotopicDataCstSPtr isotopic_data_csp = oligomer_sp->getPolymerCstSPtr()
                                             ->getPolChemDefCstSPtr()
@@ -700,7 +700,7 @@ Cleaver::accountCleavageRule(CleavageRuleSPtr cleavage_rule_sp,
           Formula rule_formula = Formula(cleavage_rule_sp->getLeftFormula());
 
           if(rule_formula.getActionFormula().isEmpty())
-            qFatalStream()
+            qFatal()
               << "Programming error. The cleavage rule's left code is "
                  "non-empty and the left formula thus cannot be empty.";
 
@@ -761,7 +761,7 @@ Cleaver::accountCleavageRule(CleavageRuleSPtr cleavage_rule_sp,
           //          << rule_formula.getActionFormula();
 
           if(rule_formula.getActionFormula().isEmpty())
-            qFatalStream()
+            qFatal()
               << "Programming error. The cleavage rule's right code is "
                  "non-empty and the right formula thus cannot be empty.";
 
@@ -1146,9 +1146,9 @@ Cleaver::cleavePartial(int partial_cleavage)
 
       // Sanity checks
       if(!m_ionizer.isValid())
-        qFatalStream() << "Programming error. The Ionizer cannot be invalid.";
+        qFatal() << "Programming error. The Ionizer cannot be invalid.";
       if(m_ionizer.isIonized())
-        qFatalStream()
+        qFatal()
           << "Programming error. The Ionizer cannot have ionized status.";
 
       // qDebug() << "BEFORE ionization:"
@@ -1244,7 +1244,7 @@ Cleaver::cleavePartial(int partial_cleavage)
   if(buffer_oligomers_count !=
      (partial_oligomers_count * (m_cleavageConfig.getStopIonizeLevel() -
                                  m_cleavageConfig.getStartIonizeLevel() + 1)))
-    qFatalStream()
+    qFatal()
       << "Programming error. The counts of Oligomer instances does not match.";
 
   // At this point we should transfer all the
@@ -1267,7 +1267,7 @@ Cleaver::cleavePartial(int partial_cleavage)
 
   // Sanity check
   if(oligomer_buffer_container.size())
-    qFatalStream()
+    qFatal()
       << "Programming error. The container cannot contain Oligomers anymore.";
 
   std::size_t generated_oligomers_count = partial_oligomers.size();
@@ -1311,7 +1311,7 @@ Cleaver::cleavePartial(int partial_cleavage)
 
   // Sanity check
   if(partial_oligomers.size())
-    qFatalStream()
+    qFatal()
       << "Programming error. The container cannot contain Oligomers anymore.";
 
   return generated_oligomers_count;
@@ -1359,7 +1359,7 @@ Cleaver::analyzeCrossLinks(OligomerCollection &oligomers)
         cross_link_sp->getFirstMonomer();
 
       if(first_cross_linked_monomer_csp == nullptr)
-        qFatalStream()
+        qFatal()
           << "Programming error. Cannot be that the CrossLink has no "
              "Monomer in its container.";
 
@@ -1439,7 +1439,7 @@ Cleaver::analyzeCrossLinks(OligomerCollection &oligomers)
   for(OligomerSPtr &oligomer_sp : cross_linked_oligomers.getOligomersRef())
     {
       if(oligomer_sp != nullptr)
-        qFatalStream() << "The oligomer was not moved.";
+        qFatal() << "The oligomer was not moved.";
     }
 
   cross_linked_oligomers.clear();
@@ -1501,7 +1501,7 @@ Cleaver::analyzeCrossLinkedOligomer(OligomerSPtr oligomer_sp,
   // appended to the clearance_oligomers.
 
   if(oligomer_sp == nullptr || oligomer_sp.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   OligomerCollection clearance_oligomers;
 
@@ -1552,7 +1552,7 @@ Cleaver::analyzeCrossLinkedOligomer(OligomerSPtr oligomer_sp,
           CrossLinkSPtr cross_link_sp = polymer_cross_links.at(index);
 
           if(cross_link_sp == nullptr)
-            qFatalStream() << "Programming error.";
+            qFatal() << "Programming error.";
 
           //  qDebug() << __FILE__ << __LINE__
           // << cross_link_sp->getName();
@@ -1683,7 +1683,7 @@ Cleaver::analyzeCrossLinkedOligomer(OligomerSPtr oligomer_sp,
                   CrossLinkSPtr cross_link_sp = polymer_cross_links.at(index);
 
                   if(cross_link_sp == nullptr)
-                    qFatalStream() << "Programming error.";
+                    qFatal() << "Programming error.";
 
                   //  qDebug() << __FILE__ << __LINE__
                   // << cross_link_sp->getName();
