@@ -199,7 +199,7 @@ CrossLink::CrossLink(PolChemDefCstSPtr pol_chem_def_csp,
     m_comment(comment)
 {
   if(polymer_cqsp == nullptr || polymer_cqsp.get() == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The pointer cannot be nullptr. If that pointer "
          "was gotten from Polymer::getCstSharedPtr(), ensure that raw pointer "
          "is "
@@ -225,7 +225,7 @@ CrossLink::CrossLink(CrossLinkerCstSPtr cross_linker_csp,
     m_comment(comment)
 {
   if(polymer_cqsp == nullptr || polymer_cqsp.get() == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The pointer cannot be nullptr. If that pointer "
          "was gotten from Polymer::getCstSharedPtr(), ensure that raw pointer "
          "is "
@@ -348,7 +348,7 @@ MonomerCstSPtr
 CrossLink::getMonomerAt(std::size_t index)
 {
   if(index >= m_monomers.size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return m_monomers.at(index);
 }
@@ -365,12 +365,12 @@ bool
 CrossLink::removeMonomerAt(std::size_t index)
 {
   if(index >= m_monomers.size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   MonomerCstSPtr monomer_csp = *(m_monomers.cbegin() + index);
 
   if(monomer_csp == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 
   return removeMonomer(monomer_csp);
 }
@@ -385,7 +385,7 @@ bool
 CrossLink::removeMonomer(MonomerCstSPtr monomer_csp)
 {
   if(monomer_csp == nullptr || monomer_csp.get() == nullptr)
-    qFatalStream() << "Cannot be that pointer is nullptr.";
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   // We will need this anyway.
   QString uuid = getUuidForMonomer(monomer_csp);
@@ -402,7 +402,7 @@ CrossLink::removeMonomer(MonomerCstSPtr monomer_csp)
       qDebug() << "The MonomerCstSPtr was not found in the container.";
 
       if(!uuid.isEmpty())
-        qFatalStream()
+        qFatal()
           << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
       return false;
@@ -422,7 +422,7 @@ CrossLink::removeMonomer(MonomerCstSPtr monomer_csp)
                  });
 
   if(the_pair_iterator_cst == m_uuidMonomerPairs.cend())
-    qFatalStream()
+    qFatal()
       << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
   m_uuidMonomerPairs.erase(the_pair_iterator_cst);
@@ -588,7 +588,7 @@ CrossLink::locationsOfOnlyExtremeSequenceMonomers(
     continuumOfLocationsOfInclusiveSequenceMonomers(location_type);
 
   if(continuum_locations.size() < 2)
-    qFatalStream()
+    qFatal()
       << "Programming error. Cannot be that less than two monomers are "
          "involved in CrossLink.";
 
@@ -632,7 +632,7 @@ std::size_t
 CrossLink::monomerIndex(MonomerCstSPtr monomer_csp, bool &ok) const
 {
   if(monomer_csp == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 
   std::vector<MonomerCstSPtr>::const_iterator the_iterator_cst =
     std::find_if(m_monomers.cbegin(),
@@ -668,7 +668,7 @@ std::size_t
 CrossLink::monomerIndex(MonomerCstRPtr monomer_crp, bool &ok) const
 {
   if(monomer_crp == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 
   std::vector<MonomerCstSPtr>::const_iterator the_iterator_cst =
     std::find_if(m_monomers.cbegin(),
@@ -823,7 +823,7 @@ CrossLink::isEncompassedByIndexRange(std::size_t start,
                                      std::size_t &out_count) const
 {
   if(mcsp_polymer == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The Polymer pointer cannot be nullptr.";
 
   // Iterate in the list of monomers, and for each monomer check if
@@ -851,7 +851,7 @@ CrossLink::isEncompassedByIndexRange(std::size_t start,
     }
 
   if((in_count + out_count) != m_monomers.size())
-    qFatalStream()
+    qFatal()
       << "The count of monomers in and out should sum to the size of "
          "the Monomer container.";
 
@@ -903,7 +903,7 @@ CrossLink::isEncompassedByIndexRangeCollection(
   std::size_t &out_count) const
 {
   if(mcsp_polymer == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The Polymer pointer cannot be nullptr.";
 
   // Iterate in the list of monomers involved in *this crossLink,
@@ -944,7 +944,7 @@ CrossLink::isEncompassedByIndexRangeCollection(
     }
 
   if((in_count + out_count) != m_monomers.size())
-    qFatalStream()
+    qFatal()
       << "The count of monomers in and out should sum to the size of "
          "the Monomer container.";
 
@@ -1129,7 +1129,7 @@ CrossLink::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
                            double &avg) const
 {
   if(mcsp_crossLinker == nullptr || mcsp_crossLinker.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   return mcsp_crossLinker->calculateMasses(isotopic_data_csp, mono, avg);
 }
@@ -1144,7 +1144,7 @@ const CrossLink &
 CrossLink::accountMasses(double &mono, double &avg, int times) const
 {
   if(mcsp_crossLinker == nullptr || mcsp_crossLinker.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   mcsp_crossLinker->accountMasses(mono, avg, times);
 
@@ -1161,7 +1161,7 @@ double
 CrossLink::getMass(Enums::MassType mass_type) const
 {
   if(mcsp_crossLinker == nullptr || mcsp_crossLinker.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   return mcsp_crossLinker->getMass(mass_type);
 }
@@ -1174,11 +1174,11 @@ QString
 CrossLink::prepareResultsTxtString()
 {
   if(mcsp_crossLinker == nullptr || mcsp_crossLinker.get() == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The CrossLinker pointer cannot be nullptr.";
 
   if(mcsp_polymer == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The Polymer pointer cannot be nullptr.";
 
   QString text;
@@ -1250,14 +1250,14 @@ QString
 CrossLink::storeMonomer(const MonomerCstSPtr &monomer_csp)
 {
   if(monomer_csp == nullptr)
-    qFatalStream() << "Cannot be that the pointer is nullptr.";
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   qDebug() << "Right before storage, there are currently" << m_monomers.size()
            << "monomers.";
 
   // Do not store an item twice.
   if(hasMonomer(monomer_csp) || !getUuidForMonomer(monomer_csp).isEmpty())
-    qFatalStream()
+    qFatal()
       << "It is prohibited to store the same MonomerCstSPtr more than once.";
 
   // Even if we get a ref to shared_ptr, the reference count increment will
@@ -1280,7 +1280,7 @@ bool
 CrossLink::hasMonomer(const MonomerCstSPtr &monomer_csp) const
 {
   if(monomer_csp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<MonomerCstSPtr>::const_iterator the_iterator_cst =
     std::find_if(m_monomers.cbegin(),
@@ -1307,7 +1307,7 @@ bool
 CrossLink::hasUuid(const MonomerCstSPtr &monomer_csp) const
 {
   if(monomer_csp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<UuidMonomerCstWPtrPair>::const_iterator the_iterator_cst =
     std::find_if(m_uuidMonomerPairs.cbegin(),
@@ -1321,7 +1321,7 @@ CrossLink::hasUuid(const MonomerCstSPtr &monomer_csp) const
 
   // Sanity check
   if(!hasMonomer(monomer_csp))
-    qFatalStream()
+    qFatal()
       << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
   return true;
@@ -1355,7 +1355,7 @@ CrossLink::getMonomerForUuid(const QString &uuid) const
   // Sanity check
 
   if(!hasMonomer(monomer_csp))
-    qFatalStream()
+    qFatal()
       << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
   return monomer_csp;
@@ -1371,7 +1371,7 @@ QString
 CrossLink::getUuidForMonomer(const MonomerCstSPtr &monomer_csp) const
 {
   if(monomer_csp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<UuidMonomerCstWPtrPair>::const_iterator the_iterator_cst =
     std::find_if(m_uuidMonomerPairs.cbegin(),
@@ -1386,7 +1386,7 @@ CrossLink::getUuidForMonomer(const MonomerCstSPtr &monomer_csp) const
     {
       // Sanity check
       if(hasMonomer(monomer_csp))
-        qFatalStream() << "Inconsistency between the m_monomers and the "
+        qFatal() << "Inconsistency between the m_monomers and the "
                           "m_uuidMonomerPairs vectors.";
 
       return QString();
@@ -1394,7 +1394,7 @@ CrossLink::getUuidForMonomer(const MonomerCstSPtr &monomer_csp) const
 
   // Sanity check
   if(!hasMonomer(monomer_csp))
-    qFatalStream() << "Inconsistency between the m_monomers and the "
+    qFatal() << "Inconsistency between the m_monomers and the "
                       "m_uuidMonomerPairs vectors.";
 
   return (*the_iterator_cst).first;
@@ -1416,7 +1416,7 @@ CrossLink::getAllMonomerUuids() const
 
   // Sanity check
   if(the_uuid_strings.size() != m_monomers.size())
-    qFatalStream()
+    qFatal()
       << "Inconsistency between the <object>_s and <uuid-object> pairs.";
 
   return the_uuid_strings;
@@ -1442,7 +1442,7 @@ CrossLink::toString() const
         mcsp_polymer->getSequenceCstRef().monomerIndex(monomer_csp, ok);
 
       if(!ok)
-        qFatalStream() << "Programming error.";
+        qFatal() << "Programming error.";
 
       text += QString(";%1;").arg(index);
     }
