@@ -360,9 +360,9 @@ bool
 CrossLinker::insertModifAt(ModifCstSPtr modif_csp, std::size_t index)
 {
   if(index >= m_modifs.size())
-    qFatalStream() << "The index is out of bounds.";
+    qFatal() << "The index is out of bounds.";
   if(modif_csp == nullptr || modif_csp.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr";
+    qFatal() << "Programming error. The pointer cannot be nullptr";
 
   m_modifs.insert(m_modifs.cbegin() + index, modif_csp);
 
@@ -378,7 +378,7 @@ bool
 CrossLinker::appendModif(ModifCstSPtr modif_csp)
 {
   if(modif_csp == nullptr || modif_csp.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr";
+    qFatal() << "Programming error. The pointer cannot be nullptr";
 
   m_modifs.push_back(modif_csp);
 
@@ -394,7 +394,7 @@ ModifCstSPtr
 CrossLinker::getModifAt(std::size_t index) const
 {
   if(index >= m_modifs.size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return m_modifs.at(index);
 }
@@ -410,7 +410,7 @@ bool
 CrossLinker::removeModifAt(std::size_t index)
 {
   if(index >= m_modifs.size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   m_modifs.erase(m_modifs.cbegin() + index);
 
@@ -926,7 +926,7 @@ CrossLinker::getMass(Enums::MassType mass_type) const
   else if(mass_type == Enums::MassType::AVG)
     return m_avg;
 
-  qFatalStream() << "Mass cannot be anything else than Enums::MassType::MONO "
+  qFatal() << "Mass cannot be anything else than Enums::MassType::MONO "
                     "or Enums::MassType::AVG.";
 
   return -1;
