@@ -228,10 +228,10 @@ Formula::Formula(const QString &formula_string, QObject *parent)
   : QObject(parent), m_actionFormula{formula_string}
 {
   m_title = removeTitle();
-  qDebug() << "The title:" << m_title;
+  // qDebug() << "The title:" << m_title;
 
   removeSpaces();
-  qDebug() << "Formula after removing spaces:" << m_actionFormula;
+  // qDebug() << "Formula after removing spaces:" << m_actionFormula;
 
   if(m_actionFormula.isEmpty())
     {
@@ -926,6 +926,36 @@ Formula::operator!=(const Formula &other) const
   return !operator==(other);
 }
 
+///////////////////// ROUNDING INDEX VALUES /////////////////////
+void
+Formula::roundIndices()
+{
+  if(!isValid())
+    {
+      qDebug() << "The formula is not valid, have you called validate().";
+      return;
+    }
+
+  // qDebug() << "The number of symbol/count pairs in the map:"
+  //          << m_symbolCountMap.size();
+
+
+  std::map<QString, double>::iterator the_iterator = m_symbolCountMap.begin();
+  std::map<QString, double>::iterator the_end_iterator = m_symbolCountMap.end();
+
+  while(the_iterator != the_end_iterator)
+    {
+      // qDebug() << "current symbol count pair:" << the_iterator->first
+      //          << the_iterator->second;
+
+      the_iterator->second = static_cast<int>(std::round(the_iterator->second));
+      ++the_iterator;
+    }
+
+  // qDebug() << "Done rounding, new formula:" << elementalComposition();
+}
+
+
 //////////////// THE SUB-FORMULAS OPERATIONS /////////////////////
 
 
@@ -2102,7 +2132,7 @@ Formula::accountMasses(bool &ok,
 
   // qDebug() << "after splitActionParts:"
   //          << "store: true ; reset: true"
-  //          << "m_actionFormula:" << m_actionFormula << "text" << toString();
+  //          << "m_actionFormula:" << m_actionFormula;
 
   // At this point m_symbolCountMap has all the symbol/count pairs needed to
   // account for the masses.
@@ -2110,8 +2140,8 @@ Formula::accountMasses(bool &ok,
   std::map<QString, double>::const_iterator iter = m_symbolCountMap.cbegin();
   std::map<QString, double>::const_iterator iter_end = m_symbolCountMap.cend();
 
-  // for(auto item : m_symbolCountMap)
-  //   qDebug() << "One symbol count item:" << item.first << "/" << item.second;
+  // for(auto &item : m_symbolCountMap)
+  //   qDebug() << "One symbol/count item:" << item.first << "/" << item.second;
 
   bool res = false;
 
@@ -2119,8 +2149,6 @@ Formula::accountMasses(bool &ok,
     {
       QString symbol = iter->first;
 
-      // qDebug() << "Getting masses for symbol:" << symbol;
-
       double mono_mass =
         isotopic_data_csp->getMonoMassBySymbol(iter->first, res);
       if(!res)
@@ -2129,7 +2157,18 @@ Formula::accountMasses(bool &ok,
           ok = false;
           return *this;
         }
-      mono += mono_mass * iter->second;
+
+      // qDebug() << qSetRealNumberPrecision(5)
+      //          << "The mono mass where the formla accounting is headed:"
+      //          << mono;
+
+      mono += mono_mass * iter->second * times;
+
+      // qDebug() << qSetRealNumberPrecision(5) << "For symbol:" << symbol
+      //          << "got mono mass:" << mono_mass
+      //          << "compounded by symbol count:" << iter->second
+      //          << "compounded by times:" << times
+      //          << "and added to returned mono mass which is now:" << mono;
 
       ok = false;
 
@@ -2140,8 +2179,18 @@ Formula::accountMasses(bool &ok,
           ok = false;
           return *this;
         }
-      avg += avg_mass * iter->second;
 
+      // qDebug() << qSetRealNumberPrecision(5)
+      //          << "The avg mass where the formla accounting is headed:" <<
+      //          avg;
+
+      avg += avg_mass * iter->second * times;
+
+      // qDebug() << qSetRealNumberPrecision(5) << "For symbol:" << symbol
+      //          << "got avg mass:" << avg_mass
+      //          << "compounded by symbol count:" << iter->second
+      //          << "compounded by times:" << times
+      //          << "and added to returned avg mass which is now:" << avg;
 
       ++iter;
     }
