@@ -194,7 +194,7 @@ FragmentationPathway::FragmentationPathway(PolChemDefCstSPtr pol_chem_def_csp,
                     "for construction of FragmentationPathway instance.";
     }
   else
-    qFatalStream()
+    qFatal()
       << "Programming error. The polymer chemistry definition version "
          "is not correct.";
 }
@@ -617,7 +617,7 @@ void
 FragmentationPathway::addRule(FragmentationRuleSPtr frag_rule_sp)
 {
   if(frag_rule_sp == nullptr || frag_rule_sp.get() == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 
   m_rules.push_back(frag_rule_sp);
 
@@ -645,10 +645,10 @@ FragmentationPathway::insertRuleAt(FragmentationRuleSPtr frag_rule_sp,
                                    std::size_t index)
 {
   if(frag_rule_sp == nullptr || frag_rule_sp.get() == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 
   if(index > m_rules.size())
-    qFatalStream() << "Programming error. Index out of bounds.";
+    qFatal() << "Programming error. Index out of bounds.";
 
   if(index == m_rules.size())
     addRule(frag_rule_sp);
@@ -674,7 +674,7 @@ void
 FragmentationPathway::removeRuleAt(size_t index)
 {
   if(index >= m_rules.size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   m_rules.erase(m_rules.begin() + index);
 }
