@@ -284,11 +284,11 @@ IndexRangeCollection::parseIndexRanges(const QString &index_ranges_string,
       int start = start_string.toInt(&ok);
 
       if(!ok)
-        qFatalStream() << "Failed to parse the IndexRange instance(s)";
+        qFatal() << "Failed to parse the IndexRange instance(s)";
       int stop = stop_string.toInt(&ok);
 
       if(!ok)
-        qFatalStream() << "Failed to parse the IndexRange instance(s)";
+        qFatal() << "Failed to parse the IndexRange instance(s)";
 
       if(location_type == Enums::LocationType::POSITION)
         {
@@ -503,7 +503,7 @@ const IndexRange &
 IndexRangeCollection::getRangeCstRefAt(qsizetype index) const
 {
   if(index >= size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return *m_ranges.at(index);
 }
@@ -517,7 +517,7 @@ IndexRange &
 IndexRangeCollection::getRangeRefAt(qsizetype index)
 {
   if(index >= size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return *m_ranges.at(index);
 }
@@ -531,7 +531,7 @@ IndexRange *
 IndexRangeCollection::getRangeAt(qsizetype index)
 {
   if(index < 0 || index >= size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return m_ranges.at(index);
 }
@@ -545,7 +545,7 @@ const QList<IndexRange *>::const_iterator
 IndexRangeCollection::getRangeCstIteratorAt(qsizetype index) const
 {
   if(index < 0 || index >= size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return m_ranges.cbegin() + index;
 }
@@ -559,7 +559,7 @@ const QList<IndexRange *>::iterator
 IndexRangeCollection::getRangeIteratorAt(qsizetype index)
 {
   if(index < 0 || index >= size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return m_ranges.begin() + index;
 }
