@@ -774,7 +774,7 @@ Ionizer::ionize(double &mono, double &avg) const
       Enums::IonizationOutcome ionization_outcome = deionize(mono, avg);
 
       if(ionization_outcome == Enums::IonizationOutcome::FAILED)
-        qFatalStream() << "Failed to deionize.";
+        qFatal() << "Failed to deionize.";
     }
 
   if(!charge())
@@ -834,10 +834,10 @@ Ionizer::ionize(double &mono, double &avg) const
   //  Now establish if we did actually change something in the process:
   if((temp_mono != mono && temp_avg == avg) ||
      (temp_mono == mono && temp_avg != avg))
-    qFatalStream() << "Programming error. Ionization failed.";
+    qFatal() << "Programming error. Ionization failed.";
 
   if(temp_mono == mono && temp_avg == avg)
-    qFatalStream() << "Programming error. Ionization failed.";
+    qFatal() << "Programming error. Ionization failed.";
 
   //  Yes, ionization changed something.
   mono = temp_mono;
@@ -926,7 +926,7 @@ Ionizer::deionize(double &mono, double &avg) const
   temp_formula.accountMasses(
     ok, mcsp_isotopicData, temp_mono, temp_avg, -m_currentStateLevel);
   if(!ok)
-    qFatalStream() << "Failed to account the masses of the ionizer formula.";
+    qFatal() << "Failed to account the masses of the ionizer formula.";
 
   qDebug()
     << qSetRealNumberPrecision(10)
@@ -938,7 +938,7 @@ Ionizer::deionize(double &mono, double &avg) const
   if((temp_mono != mono && temp_avg == avg) ||
      (temp_mono == mono && temp_avg != avg) ||
      (temp_mono == mono && temp_avg == avg))
-    qFatalStream() << "The deionization failed.";
+    qFatal() << "The deionization failed.";
 
   //  Yes, deionization changed something.
   mono = temp_mono;
@@ -984,7 +984,7 @@ Ionizer::molecularMasses(double &mono, double &avg) const
   Enums::IonizationOutcome outcome = deionize(temp_mono, temp_avg);
 
   if(outcome == Enums::IonizationOutcome::FAILED)
-    qFatalStream() << "Programming error. Failed to deionize.";
+    qFatal() << "Programming error. Failed to deionize.";
 
   if(outcome == Enums::IonizationOutcome::DEIONIZED)
     {
