@@ -212,7 +212,7 @@ Isotope::Isotope(const QString &name,
     {
       QString errors = Utils::joinErrorList(error_list, "\n");
 
-      qWarning().noquote()
+      qDebug().noquote()
         << "The constructed isotope is not valid, with errors:\n"
         << errors;
     }
@@ -225,7 +225,7 @@ parent.
 */
 Isotope::Isotope(const Isotope &other, QObject *parent): QObject(parent)
 {
-  qDebug() << "Constructing using reference.";
+  // qDebug() << "Constructing using reference.";
 
   m_name        = other.m_name;
   m_symbol      = other.m_symbol;
@@ -239,7 +239,7 @@ Isotope::Isotope(const Isotope &other, QObject *parent): QObject(parent)
     {
       QString errors = Utils::joinErrorList(error_list, "\n");
 
-      qWarning().noquote()
+      qDebug().noquote()
         << "The copy-constructed isotope is not valid, with errors:\n"
         << errors;
     }
@@ -253,7 +253,7 @@ parent.
 Isotope::Isotope(const Isotope *other_p, QObject *parent): QObject(parent)
 {
   Q_ASSERT(other_p != nullptr);
-  qDebug() << "Constructing using pointer.";
+  // qDebug() << "Constructing using pointer.";
 
   m_name        = other_p->m_name;
   m_symbol      = other_p->m_symbol;
@@ -267,7 +267,7 @@ Isotope::Isotope(const Isotope *other_p, QObject *parent): QObject(parent)
     {
       QString errors = Utils::joinErrorList(error_list, "\n");
 
-      qWarning().noquote()
+      qDebug().noquote()
         << "The copy-constructed isotope is not valid, with errors:\n"
         << errors;
     }
@@ -293,7 +293,7 @@ Isotope::Isotope(const QString &text, QObject *parent): QObject(parent)
   // This is somehow the reverse of toString().
 
   if(!initialize(text))
-    qWarning() << "The initialization failed using text:" << text;
+    qDebug() << "The initialization failed using text:" << text;
 }
 
 /*!
@@ -385,7 +385,7 @@ Isotope::initialize(const QString &name,
 
   if(!regexp.match(local_text).hasMatch())
     {
-      qWarning() << "Failed to initialize the element's name.";
+      qDebug() << "Failed to initialize the element's name.";
     }
   else
     m_name = local_text;
@@ -395,19 +395,19 @@ Isotope::initialize(const QString &name,
   regexp.setPattern("^[A-Z][a-z]*$");
 
   if(!regexp.match(local_text).hasMatch())
-    qWarning() << "Failed to initialize the element's symbol.";
+    qDebug() << "Failed to initialize the element's symbol.";
   else
     m_symbol = local_text;
 
   //////// The isotope's mass
   if(mass < 0)
-    qWarning() << "Failed to initialize the isotope's mass.";
+    qDebug() << "Failed to initialize the isotope's mass.";
   else
     m_mass = mass;
 
   //////// The isotope's probability
   if(probability < 0 || probability > 1)
-    qWarning() << "Failed to initialize the isotope's probability.";
+    qDebug() << "Failed to initialize the isotope's probability.";
   else
     m_probability = probability;
 
@@ -424,8 +424,8 @@ Isotope::initialize(const QString &name,
       for(const QString &error : error_list)
         errors.append(QString("%1\n").arg(error));
 
-      qWarning().noquote()
-        << "The initialized isotope is not valid, with errors:" << errors;
+      qDebug().noquote() << "The initialized isotope is not valid, with errors:"
+                         << errors;
     }
 
   return m_isValid;
@@ -443,23 +443,20 @@ values to initalize all the member data.
 Returns true if the string contained valid substrings that successfully
 initialized the \l{Isotope}, false otherwise.
 
-\sa Isotope(const QString &text, QObject *parent), initialize(const QString &name,
-                    const QString &symbol,
-                    double mass,
-                    double probability)
+\sa Isotope(const QString &text, QObject *parent), initialize(const QString
+&name, const QString &symbol, double mass, double probability)
 */
 bool
 Isotope::initialize(const QString &text)
 {
-  qDebug() << "Initializing Isotope with text:" << text;
+  // qDebug() << "Initializing Isotope with text:" << text;
 
   // Start by resetting this Isotope instance (sets m_isValid to false)
   clear();
 
   if(text.isEmpty())
     {
-      qCritical()
-        << "The text used to initialize the Isotope instance is empty.";
+      qDebug() << "The text used to initialize the Isotope instance is empty.";
       m_isValid = false;
       return m_isValid;
     }
@@ -469,12 +466,12 @@ Isotope::initialize(const QString &text)
   // only single-space substrings.
 
   QString local_text = text.simplified();
-  qDebug() << "After simplification, the text becomes:" << local_text;
+  // qDebug() << "After simplification, the text becomes:" << local_text;
 
   QStringList string_list = local_text.split(',');
 
-  qDebug() << "After splitting text at commas, count of the subtext strings:"
-           << string_list.size();
+  // qDebug() << "After splitting text at commas, count of the subtext strings:"
+  //          << string_list.size();
 
   // We may be reading data from a line that comes from an old version of
   // isotopic data files that contain much more information than from newer
@@ -513,15 +510,13 @@ values to initalize all the member data.
 Returns true if the string contained valid substrings that successfully
 initialized the \l{Isotope}, false otherwise.
 
-\sa Isotope(const QString &text, QObject *parent), initialize(const QString &name,
-                    const QString &symbol,
-                    double mass,
-                    double probability)
+\sa Isotope(const QString &text, QObject *parent), initialize(const QString
+&name, const QString &symbol, double mass, double probability)
 */
 bool
 Isotope::initializeVersion1(const QString &text)
 {
-  qDebug() << "Initializing Isotope with text:" << text;
+  // qDebug() << "Initializing Isotope with text:" << text;
 
   // This version has a set of data matching this structure:
 
@@ -545,8 +540,7 @@ Isotope::initializeVersion1(const QString &text)
 
   if(text.isEmpty())
     {
-      qCritical()
-        << "The text used to initialize the Isotope instance is empty.";
+      qDebug() << "The text used to initialize the Isotope instance is empty.";
       m_isValid = false;
       return m_isValid;
     }
@@ -560,12 +554,12 @@ Isotope::initializeVersion1(const QString &text)
   // only single-space substrings.
 
   QString local_text = text.simplified();
-  qDebug() << "After simplification, the text becomes:" << local_text;
+  // qDebug() << "After simplification, the text becomes:" << local_text;
 
   QStringList string_list = local_text.split(',');
 
-  qDebug() << "After splitting text at commas, count of the subtext strings:"
-           << string_list.size();
+  // qDebug() << "After splitting text at commas, count of the subtext strings:"
+  //          << string_list.size();
 
   if(string_list.size() != 10)
     {
@@ -636,21 +630,20 @@ text at ',' delimiter defines what data element it corresponds to.
 Returns true if the string contained valid substrings that successfully
 initialized the \l{Isotope}, false otherwise.
 
-\sa Isotope(const QString &text, QObject *parent), initialize(const QString &name, const QString
-&symbol, double mass, double probability)
+\sa Isotope(const QString &text, QObject *parent), initialize(const QString
+&name, const QString &symbol, double mass, double probability)
 */
 bool
 Isotope::initializeVersion2(const QString &text)
 {
-  qDebug() << "Initializing Isotope with text:" << text;
+  // qDebug() << "Initializing Isotope with text:" << text;
 
   // Start by resetting this Isotope instance (sets m_isValid to false)
   clear();
 
   if(text.isEmpty())
     {
-      qCritical()
-        << "The text used to initialize the Isotope instance is empty.";
+      qDebug() << "The text used to initialize the Isotope instance is empty.";
       m_isValid = false;
       return m_isValid;
     }
@@ -664,12 +657,12 @@ Isotope::initializeVersion2(const QString &text)
   // only single-space substrings.
 
   QString local_text = text.simplified();
-  qDebug() << "After simplification, the text becomes:" << local_text;
+  // qDebug() << "After simplification, the text becomes:" << local_text;
 
   QStringList string_list = local_text.split(',');
 
-  qDebug() << "After splitting text at commas, count of the subtext strings:"
-           << string_list.size();
+  // qDebug() << "After splitting text at commas, count of the subtext strings:"
+  //          << string_list.size();
 
   // qDebug() << "Expecting " << static_cast<int>(IsotopeFields::LAST)
   //          << "comma-separated fields for isotope-describing text line."
@@ -677,7 +670,7 @@ Isotope::initializeVersion2(const QString &text)
 
   if(string_list.size() != static_cast<int>(IsotopeFields::LAST))
     {
-      qWarning() << "The text does not match an Isotope definition.";
+      qDebug() << "The text does not match an Isotope definition.";
       m_isValid = false;
       return m_isValid;
     }
@@ -689,7 +682,7 @@ Isotope::initializeVersion2(const QString &text)
   regexp.setPattern("^[a-z]+$");
   if(!regexp.match(temp_value_string).hasMatch())
     {
-      qWarning() << "Failed to extract the element name.";
+      qDebug() << "Failed to extract the element name.";
       m_isValid = false;
       return m_isValid;
     }
@@ -701,7 +694,7 @@ Isotope::initializeVersion2(const QString &text)
   regexp.setPattern("^[A-Z][a-z]*$");
   if(!regexp.match(temp_value_string).hasMatch())
     {
-      qWarning() << "Failed to extract the element symbol.";
+      qDebug() << "Failed to extract the element symbol.";
       m_isValid = false;
       return m_isValid;
     }
@@ -713,7 +706,7 @@ Isotope::initializeVersion2(const QString &text)
       &ok);
   if(!ok)
     {
-      qWarning() << "Failed to extract the isotope mass.";
+      qDebug() << "Failed to extract the isotope mass.";
       m_isValid = false;
       return m_isValid;
     }
@@ -726,7 +719,7 @@ Isotope::initializeVersion2(const QString &text)
                         .toDouble(&ok);
   if(!ok || temp_value_double > 1)
     {
-      qWarning() << "Failed to extract the isotope probability.";
+      qDebug() << "Failed to extract the isotope probability.";
       m_isValid = false;
       return m_isValid;
     }
@@ -746,8 +739,8 @@ Isotope::initializeVersion2(const QString &text)
       for(const QString &error : error_list)
         errors.append(QString("%1\n").arg(error));
 
-      qWarning().noquote()
-        << "The initialized isotope is not valid, with errors:" << errors;
+      qDebug().noquote() << "The initialized isotope is not valid, with errors:"
+                         << errors;
     }
 
   return m_isValid;
@@ -764,8 +757,8 @@ Isotope::setName(const QString &name)
   QRegularExpression regexp("^[a-z]+$");
   if(!regexp.match(name).hasMatch())
     {
-      qWarning() << "Failed to set the element name. The name should be all "
-                    "lower-case. Isotope left unchanged.";
+      qDebug() << "Failed to set the element name. The name should be all "
+                  "lower-case. Isotope left unchanged.";
       m_isValid = false;
     }
 
@@ -794,7 +787,7 @@ Isotope::setSymbol(const QString &symbol)
   QRegularExpression regexp("^[A-Z][a-z]*$");
   if(!regexp.match(symbol).hasMatch())
     {
-      qWarning() << "Failed to set the element symbol. Isotope left unchanged.";
+      qDebug() << "Failed to set the element symbol. Isotope left unchanged.";
       m_isValid = false;
     }
 
@@ -822,7 +815,7 @@ Isotope::setMass(double mass)
 {
   if(mass < 0)
     {
-      qWarning() << "Failed to set the mass. Isotope left unchanged.";
+      qDebug() << "Failed to set the mass. Isotope left unchanged.";
       m_isValid = false;
     }
 
@@ -850,7 +843,7 @@ Isotope::setProbability(double probability)
 {
   if(probability < 0 || probability > 1)
     {
-      qWarning() << "Failed to set the probability. Isotope left unchanged.";
+      qDebug() << "Failed to set the probability. Isotope left unchanged.";
       m_isValid = false;
     }
 
@@ -886,7 +879,7 @@ if(!regexp.match(local_text).hasMatch())
 {
 error_msg = "Failed to validate the element's symbol.";
 error_list_p->push_back(error_msg);
-qWarning() << error_msg;
+qDebug() << error_msg;
 }
 }
 \endcode
@@ -910,7 +903,7 @@ Isotope::validate(ErrorList *error_list_p)
     {
       error_msg = "Failed to validate the element's name.";
       error_list_p->push_back(error_msg);
-      qWarning() << error_msg;
+      qDebug() << error_msg;
     }
   m_name = local_text;
 
@@ -922,7 +915,7 @@ Isotope::validate(ErrorList *error_list_p)
     {
       error_msg = "Failed to validate the element's symbol.";
       error_list_p->push_back(error_msg);
-      qWarning() << error_msg;
+      qDebug() << error_msg;
     }
   m_symbol = local_text;
 
@@ -931,17 +924,17 @@ Isotope::validate(ErrorList *error_list_p)
     {
       error_msg = "Failed to validate the isotope's mass.";
       error_list_p->push_back(error_msg);
-      qWarning() << error_msg;
+      qDebug() << error_msg;
     }
 
   //////// The element probability
   if(m_probability < 0 || m_probability > 1)
     {
-      qDebug() << "The probability:" << m_probability;
+      // qDebug() << "The probability:" << m_probability;
 
       error_msg = "Failed to validate the isotope's probability.";
       error_list_p->push_back(error_msg);
-      qWarning() << error_msg;
+      qDebug() << error_msg;
     }
 
   if(error_list_p->size() > previous_error_count)
@@ -1031,7 +1024,7 @@ Isotope::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register Isotope class: engine is null";
+      qDebug() << "Cannot register Isotope class: engine is null";
       return;
     }
 
