@@ -83,6 +83,8 @@ namespace libXpertMassCore
 
 \brief The IsotopicClusterGenerator class provides the features needed to model
 isotopic clusters starting from (elemental-composition, charge) pairs.
+Neutral analytes can have their isotopic cluster modelle by setting the charge
+to 0.
 
 The modelling uses the member isotopic data. The generated isotopic clusters
 only contain cluster centroid peaks. If peaks should have a profile, then they
@@ -187,6 +189,8 @@ MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_formulaChargePairs
 MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_isotopicClusterChargePairs
 
 \brief The set of (isotopic cluster, charge) pairs.
+
+Neutral analytes will have the charge set to 0.
 */
 
 
@@ -406,7 +410,7 @@ IsotopicClusterGenerator::validateAllFormulas()
 \list
 
 \li \a element_count: the number of elements in the chemical composition.
-\li \a charge: the charge of the analyte.
+\li \a charge: the charge of the analyte. Might be 0 for neutral analytes.
 
 \li \a per_element_isotopes_count_array_p: pointer to int array. This array
 lists the number of isotopes that each element has. Typically, C has 2, O has 3,
@@ -491,7 +495,15 @@ IsotopicClusterGenerator::runIsotopicDataCalculations(
   while(iso.advanceToNextConfiguration())
     {
       double iso_prob = iso.prob();
-      double iso_mz   = iso.mass() / charge;
+      double iso_mz   = 0;
+      if(charge)
+        {
+          iso_mz = iso.mass() / charge;
+        }
+      else
+        {
+          iso_mz = iso.mass();
+        }
 
       // qDebug() << "For current configuration (charge accounted for):" <<
       // iso_mz
@@ -1071,8 +1083,8 @@ IsotopicClusterGenerator::run()
 
       if(!pair.first->size())
         {
-          qFatal() << "The isotopic cluster is empty for formula: %s",
-            formula_charge_pair.first.toLatin1().data();
+          qFatal() << "The isotopic cluster is empty for formula:"
+                   << formula_charge_pair.first;
         }
 
       m_isotopicClusterChargePairs.push_back(pair);
