@@ -1340,13 +1340,13 @@ IsotopicData::isMonoMassIsotope(IsotopeCstQSPtr isotope_cqsp)
   // all the isotopes having the same symbol.
 
   if(isotope_cqsp == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The isotope pointer cannot be nullptr.";
 
   QString symbol(isotope_cqsp->getSymbol());
 
   if(!m_symbolMonoMassMap.contains(symbol))
-    qFatalStream() << "Programming error. The symbol was not found in the map.";
+    qFatal() << "Programming error. The symbol was not found in the map.";
 
   double mass = m_symbolMonoMassMap.value(symbol);
 
