@@ -62,12 +62,12 @@ namespace libXpertMassCore
 mass spectrometric data using the CBOR (Concise Binary Object Representation)
 container streaming classes.
 
-The data transported using CBOR is first qualified using the \l{Enums::MassDataType}
-enum. The data are packed following that mass data type specification.
+The data transported using CBOR is first qualified using the
+\l{Enums::MassDataType} enum. The data are packed following that mass data type
+specification.
 */
 
 
-
 /*!
  \brief Constructs a MassDataCborBaseHandler instance setting parent to \a
  parent_p.
