@@ -184,8 +184,8 @@ MassDataServer::serveData(const QByteArray &byte_array_to_serve)
             }
           else
             {
-              qWarning() << "The data written to the socket were less than the "
-                            "initial data.";
+              qDebug() << "The data written to the socket were less than the "
+                          "initial data.";
             }
         }
     }
