@@ -51,7 +51,6 @@
 #include "MsXpS/libXpertMassCore/Utils.hpp"
 #include "MsXpS/libXpertMassCore/MassPeakShaper.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -110,7 +109,7 @@ peak shape.
 /*!
 \brief Constructs a MassPeakShaper instance.
 */
-MassPeakShaper::MassPeakShaper() : m_peakCentroid(0, 0)
+MassPeakShaper::MassPeakShaper(): m_peakCentroid(0, 0)
 {
 }
 
@@ -130,7 +129,6 @@ MassPeakShaper::MassPeakShaper(double mz,
 {
 }
 
-
 /*!
 \brief Constructs a MassPeakShaper instance.
 
@@ -146,7 +144,6 @@ MassPeakShaper::MassPeakShaper(const pappso::DataPoint &data_point,
   // qDebug()"m_config:" << m_config.asText(800);
 }
 
-
 /*!
 \brief Constructs a MassPeakShaper instance as a copy of \a other.
 */
@@ -173,7 +170,6 @@ MassPeakShaper::setPeakCentroid(const pappso::DataPoint &peak_centroid_data)
   m_peakCentroid = peak_centroid_data;
 }
 
-
 /*!
 \brief Returns the peak centroid data.
 */
@@ -210,7 +206,6 @@ MassPeakShaper::setConfig(const MassPeakShaperConfig &config)
   m_config.initialize(config);
 }
 
-
 /*!
 \brief Returns the configuration driving the peak shaping process.
 */
@@ -234,7 +229,6 @@ MassPeakShaper::computePeakShape()
     return computeLorentzianPeakShape();
 }
 
-
 /*!
 \brief Computes the peak shape of the peak centroid.
 
@@ -257,7 +251,6 @@ MassPeakShaper::computePeakShape(double mz,
     return computeLorentzianPeakShape(mz, intensity, config);
 }
 
-
 /*!
 \brief Computes the Gaussian peak shape of the peak centroid.
 */
@@ -274,7 +267,6 @@ MassPeakShaper::computeGaussianPeakShape()
   return m_trace.size();
 }
 
-
 /*!
 \brief Computes the Gaussian peak shape of the peak centroid.
 
@@ -305,7 +297,7 @@ MassPeakShaper::computeGaussianPeakShape(double mz,
   if(!local_config.resolve(error_list))
     {
       qDebug() << "Failed to resolve the MassPeakShaperConfig with errors:\n"
-      << Utils::joinErrorList(error_list, "\n");
+               << Utils::joinErrorList(error_list, "\n");
       return trace;
     }
 
@@ -347,10 +339,11 @@ MassPeakShaper::computeGaussianPeakShape(double mz,
 
   double mz_step = local_config.getMzStep();
 
-  double left_point =
-    mz - ((double)FWHM_PEAK_SPAN_FACTOR / 2 * local_config.getFwhm());
-  double right_point =
-    mz + ((double)FWHM_PEAK_SPAN_FACTOR / 2 * local_config.getFwhm());
+  double half_peak_width_with_lateral_margins =
+    (double)FWHM_PEAK_SPAN_FACTOR / 2 * local_config.getFwhm();
+
+  double left_point  = mz - (half_peak_width_with_lateral_margins);
+  double right_point = mz + (half_peak_width_with_lateral_margins);
 
   // qDebug() << "left m/z:" << left_point;
   // qDebug() << "right m/z:" << right_point;
@@ -418,11 +411,11 @@ MassPeakShaper::computeLorentzianPeakShape(double mz,
   ErrorList error_list;
 
   if(!local_config.resolve(error_list))
-  {
-    qDebug() << "Failed to resolve the MassPeakShaperConfig with errors:\n"
-    << Utils::joinErrorList(error_list, "\n");
-    return trace;
-  }
+    {
+      qDebug() << "Failed to resolve the MassPeakShaperConfig with errors:\n"
+               << Utils::joinErrorList(error_list, "\n");
+      return trace;
+    }
 
   // qDebug() << "The peak shaper configuration:" << m_config.toString();
 
