@@ -1155,7 +1155,7 @@ Modif::getMass(Enums::MassType mass_type)
   else if(mass_type == Enums::MassType::AVG)
     return m_avg;
   else
-    qFatalStream() << "Not possible to ask a mass that is not MONO nor AVG";
+    qFatal() << "Not possible to ask a mass that is not MONO nor AVG";
 
   return -1;
 }
