@@ -620,7 +620,7 @@ Monomer::modify(const Modif &modif, bool override, ErrorList *error_list_p)
   ModifSPtr modif_sp = std::make_shared<Modif>(modif);
 
   if(modif_sp == nullptr || modif_sp.get() == nullptr)
-    qFatalStream() << "Failed to allocated new Modif object.";
+    qFatal() << "Failed to allocated new Modif object.";
 
   QString uuid = storeModif(modif_sp);
 
@@ -681,10 +681,10 @@ Monomer::unmodify(const QString &uuid)
   if((*the_iterator).second.expired() ||
      (*the_iterator).second.lock() == nullptr ||
      !hasModif((*the_iterator).second.lock()))
-    qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+    qFatal() << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
   if(!removeModif((*the_iterator).second.lock()))
-    qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+    qFatal() << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
   return true;
 }
@@ -702,7 +702,7 @@ Monomer::unmodify()
 
   // Sanity check
   if(m_modifs.size() != m_uuidModifPairs.size())
-    qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+    qFatal() << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
   m_modifs.clear();
   m_uuidModifPairs.clear();
@@ -1232,7 +1232,7 @@ Monomer::getMass(Enums::MassType mass_type) const
   else if(mass_type == Enums::MassType::AVG)
     return m_avg;
 
-  qFatalStream() << "Mass cannot be anything else than Enums::MassType::MONO "
+  qFatal() << "Mass cannot be anything else than Enums::MassType::MONO "
                     "or Enums::MassType::AVG.";
 
   return -1;
@@ -1815,14 +1815,14 @@ QString
 Monomer::storeModif(const ModifSPtr &modif_sp)
 {
   if(modif_sp == nullptr)
-    qFatalStream() << "The provided ModifSPtr is nullptr.";
+    qFatal() << "The provided ModifSPtr is nullptr.";
 
   qDebug() << "Right before storage, there are currently" << m_modifs.size()
            << "modifications.";
 
   // Do not store an item twice.
   if(hasModif(modif_sp) || !getUuidForModif(modif_sp).isEmpty())
-    qFatalStream()
+    qFatal()
       << "It is prohibited to store the same ModifSPtr more than once.";
 
   qDebug() << "Ok, we can go on.";
@@ -1853,7 +1853,7 @@ Monomer::storeModif(const Modif &modif)
 
   if(modif_sp == nullptr)
     {
-      qFatalStream() << "Failed to allocate ModifSPtr.";
+      qFatal() << "Failed to allocate ModifSPtr.";
       return "";
     }
 
@@ -1868,7 +1868,7 @@ bool
 Monomer::hasModif(const ModifSPtr &modif_sp) const
 {
   if(modif_sp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<ModifSPtr>::const_iterator the_iterator_cst =
     std::find_if(m_modifs.cbegin(),
@@ -1887,7 +1887,7 @@ Monomer::hasModif(const ModifSPtr &modif_sp) const
                      });
 
       if(the_pair_iterator_cst != m_uuidModifPairs.cend())
-        qFatalStream()
+        qFatal()
           << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
       return false;
@@ -1904,7 +1904,7 @@ bool
 Monomer::hasUuid(const ModifSPtr &modif_sp) const
 {
   if(modif_sp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<UuidModifWPtrPair>::const_iterator the_iterator_cst =
     std::find_if(m_uuidModifPairs.cbegin(),
@@ -1919,7 +1919,7 @@ Monomer::hasUuid(const ModifSPtr &modif_sp) const
   // Sanity check
 
   if(!hasModif(modif_sp))
-    qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+    qFatal() << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
   return true;
 }
@@ -1953,7 +1953,7 @@ Monomer::getModifForUuid(const QString &uuid) const
   // Sanity check
 
   if(!hasModif(modif_sp))
-    qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+    qFatal() << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
   return modif_sp;
 }
@@ -1967,7 +1967,7 @@ QString
 Monomer::getUuidForModif(const ModifSPtr &modif_sp) const
 {
   if(modif_sp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<UuidModifWPtrPair>::const_iterator the_iterator_cst =
     std::find_if(m_uuidModifPairs.cbegin(),
@@ -1982,7 +1982,7 @@ Monomer::getUuidForModif(const ModifSPtr &modif_sp) const
     {
       // Sanity check
       if(hasModif(modif_sp))
-        qFatalStream() << "Inconsistency between the m_modifs and the "
+        qFatal() << "Inconsistency between the m_modifs and the "
                           "m_uuidModifPairs vectors.";
 
       return QString();
@@ -1990,7 +1990,7 @@ Monomer::getUuidForModif(const ModifSPtr &modif_sp) const
 
   // Sanity check
   if(!hasModif(modif_sp))
-    qFatalStream()
+    qFatal()
       << "Inconsistency between the m_modifs and the m_uuidModifPairs vectors.";
 
   return (*the_iterator_cst).first;
@@ -2012,7 +2012,7 @@ Monomer::getAllModifUuids() const
 
   // Sanity check
   if(the_uuid_strings.size() != m_modifs.size())
-    qFatalStream()
+    qFatal()
       << "Inconsistency between the <object>_s and <uuid-object> pairs.";
 
   return the_uuid_strings;
@@ -2046,7 +2046,7 @@ bool
 Monomer::removeModif(ModifSPtr modif_sp)
 {
   if(modif_sp == nullptr || modif_sp.get() == nullptr)
-    qFatalStream() << "Cannot be that pointer is nullptr.";
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   // We will need this anyway.
   QString uuid = getUuidForModif(modif_sp);
@@ -2065,7 +2065,7 @@ Monomer::removeModif(ModifSPtr modif_sp)
       qDebug() << "The ModifSPtr was not found in the container.";
 
       if(!uuid.isEmpty())
-        qFatalStream()
+        qFatal()
           << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
       return false;
@@ -2085,7 +2085,7 @@ Monomer::removeModif(ModifSPtr modif_sp)
                  });
 
   if(the_pair_iterator_cst == m_uuidModifPairs.cend())
-    qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+    qFatal() << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
   m_uuidModifPairs.erase(the_pair_iterator_cst);
 
