@@ -624,7 +624,7 @@ Oligomer::setMass(Enums::MassType mass_type, double mass)
   else if(mass_type == Enums::MassType::AVG)
     m_avg = mass;
   else
-    qFatalStream() << "The mass_type needs to be either MONO or AVG.";
+    qFatal() << "The mass_type needs to be either MONO or AVG.";
 }
 
 /*!
@@ -646,7 +646,7 @@ double
 Oligomer::getMass(Enums::MassType mass_type) const
 {
   if(mass_type != Enums::MassType::MONO && mass_type != Enums::MassType::AVG)
-    qFatalStream() << "The mass_type needs to be either MONO or AVG.";
+    qFatal() << "The mass_type needs to be either MONO or AVG.";
 
   if(mass_type == Enums::MassType::MONO)
     return m_mono;
@@ -662,7 +662,7 @@ double &
 Oligomer::getMassRef(Enums::MassType mass_type)
 {
   if(mass_type != Enums::MassType::MONO && mass_type != Enums::MassType::AVG)
-    qFatalStream() << "The mass_type needs to be either MONO or AVG.";
+    qFatal() << "The mass_type needs to be either MONO or AVG.";
 
   if(mass_type == Enums::MassType::MONO)
     return m_mono;
@@ -700,7 +700,7 @@ bool
 Oligomer::addCrossLink(CrossLinkSPtr cross_link_sp)
 {
   if(cross_link_sp == nullptr || cross_link_sp.get() == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   // Add the cross-link only if it does not exist already. Return true
   // only if the crossLink has been added.
@@ -805,7 +805,7 @@ Oligomer::getLeftEndMonomerCstSPtr() const
 
 
   if(index >= mcsp_polymer->getSequenceCstRef().size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return mcsp_polymer->getSequenceCstRef().getMonomerCstSPtrAt(index);
 }
@@ -836,7 +836,7 @@ Oligomer::getRightEndMonomerCstSPtr() const
     return nullptr;
 
   if(index >= mcsp_polymer->getSequenceCstRef().size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return mcsp_polymer->getSequenceCstRef().getMonomerCstSPtrAt(index);
 }
@@ -870,7 +870,7 @@ Oligomer::getMonomerCstSPtrAt(std::size_t index) const
     }
 
   if(index >= mcsp_polymer->getSequenceCstRef().size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return mcsp_polymer->getSequenceCstRef().getMonomerCstSPtrAt(index);
 }
@@ -1143,7 +1143,7 @@ Oligomer::encompasses(std::size_t index) const
     }
 
   if(index >= mcsp_polymer->getSequenceCstRef().size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   return m_calcOptions.getIndexRangeCollectionCstRef().encompassIndex(index);
 }
