@@ -140,7 +140,7 @@ PkaPhPi::PkaPhPi(PolChemDefCstSPtr pol_chem_def_csp,
       << "Creating PkaPhPi instance without polymer chemistry definition.";
 
   if(polymer_cqsp == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 }
 
 /*!
@@ -1143,7 +1143,7 @@ PkaPhPi::accountMonomerModif(const Monomer &monomer,
           return ++count;
         }
       else
-        qFatalStream() << "Programming error.";
+        qFatal() << "Programming error.";
 
       // Whatever we should do with this monomer's chemgroup, we should
       // take into account the modification itself that might have brought
