@@ -1398,7 +1398,7 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
   qDebug() << "Rendering PolChemDef file VERSION 1.";
 
   if(pol_chem_def_sp == nullptr && pol_chem_def_sp.get() == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The PolChemDef pointer cannot be nullptr.";
 
   // qDebug() << "The PolChemDef *:" << pol_chem_def_sp.get()
@@ -1836,7 +1836,7 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
   // qDebug() << "Rendering PolChemDef file VERSION 2.";
 
   if(pol_chem_def_sp == nullptr && pol_chem_def_sp.get() == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The PolChemDef pointer cannot be nullptr.";
 
   // qDebug() << "The PolChemDef *:" << pol_chem_def_sp.get()
@@ -2267,7 +2267,7 @@ bool
 PolChemDef::renderXmlPolChemDefFile(PolChemDefSPtr pol_chem_def_sp)
 {
   if(pol_chem_def_sp == nullptr && pol_chem_def_sp.get() == nullptr)
-    qFatalStream()
+    qFatal()
       << "Programming error. The PolChemDef pointer cannot be nullptr.";
 
   // qDebug() << "The PolChemDef *:" << pol_chem_def_sp.get()
