@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -43,7 +43,6 @@
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/PolChemDefSpec.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -85,13 +84,13 @@ protein-1-letter/protein-1-letter.xml.
 */
 
 /*!
-\brief Constructs a polymer chemistry definition specification instance using \a name as the PolChemDef name.
+\brief Constructs a polymer chemistry definition specification instance using \a
+name as the PolChemDef name.
 */
-PolChemDefSpec::PolChemDefSpec(const QString &name) : m_name(name)
+PolChemDefSpec::PolChemDefSpec(const QString &name): m_name(name)
 {
 }
 
-
 /*!
 \brief Destroys the polymer chemistry definition specification instance.
 */
@@ -149,6 +148,7 @@ PolChemDefSpec::dirPath()
   QDir dir(fileInfo.dir());
   return dir.absolutePath();
 }
+
 // GCOV_EXCL_STOP
 
 } // namespace libXpertMassCore
