@@ -214,12 +214,12 @@ Sequence::setSequence(const QString &sequence,
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
     {
-      qFatalStream() << "Programming error. The PolChemDef pointer is nullptr.";
+      qFatal() << "Programming error. The PolChemDef pointer is nullptr.";
     }
 
   if(!mcsp_polChemDef->isValid())
     {
-      qFatalStream() << "Programming error. The PolChemDef is not valid.";
+      qFatal() << "Programming error. The PolChemDef is not valid.";
     }
 
   m_monomers.clear();
@@ -257,10 +257,10 @@ Sequence::appendSequence(const QString &sequence,
                          std::vector<std::size_t> &failing_indices)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qFatalStream() << "The PolChemDef pointer is nullptr!";
+    qFatal() << "The PolChemDef pointer is nullptr!";
 
   if(!mcsp_polChemDef->isValid())
-    qFatalStream() << "The PolChemDef is not valid!";
+    qFatal() << "The PolChemDef is not valid!";
 
   if(sequence.isEmpty())
     return 0;
@@ -331,7 +331,7 @@ Sequence::getSequence(std::size_t start_index,
     }
 
   if(start_index > stop_index)
-    qFatalStream() << "Programming error, please order the indices: ["
+    qFatal() << "Programming error, please order the indices: ["
                    << start_index << "-" << stop_index << "]";
 
   // We want the last index to be included in the range.
@@ -557,7 +557,7 @@ MonomerCstRPtr
 Sequence::getMonomerCstRPtrAt(std::size_t index) const
 {
   if(index >= m_monomers.size())
-    qFatalStream() << "Index is out of bounds.";
+    qFatal() << "Index is out of bounds.";
 
   return m_monomers.at(index).get();
 }
@@ -572,7 +572,7 @@ MonomerRPtr
 Sequence::getMonomerRPtrAt(std::size_t index)
 {
   if(index >= m_monomers.size())
-    qFatalStream() << "Index is out of bounds.";
+    qFatal() << "Index is out of bounds.";
 
   return m_monomers.at(index).get();
 }
@@ -587,7 +587,7 @@ MonomerSPtr
 Sequence::getMonomerCstSPtrAt(std::size_t index) const
 {
   if(index >= m_monomers.size())
-    qFatalStream() << "Programming error. Index is out of bounds:" << index
+    qFatal() << "Programming error. Index is out of bounds:" << index
                    << "with monomer count:" << m_monomers.size();
 
   return m_monomers.at(index);
@@ -603,7 +603,7 @@ MonomerSPtr
 Sequence::getMonomerSPtrAt(std::size_t index)
 {
   if(index >= m_monomers.size())
-    qFatalStream() << "Index is out of bounds.";
+    qFatal() << "Index is out of bounds.";
 
   return m_monomers.at(index);
 }
@@ -679,7 +679,7 @@ std::size_t
 Sequence::monomerIndex(MonomerCstRPtr monomer_crp, bool &ok) const
 {
   if(monomer_crp == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 
   std::vector<MonomerSPtr>::const_iterator the_iterator_cst =
     std::find_if(m_monomers.cbegin(),
@@ -718,7 +718,7 @@ Sequence::nextCode(const QString &sequence,
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr ||
      !mcsp_polChemDef->isValid())
-    qFatalStream()
+    qFatal()
       << "Programming error. It is not possible that the PolChemDef be "
          "undefined or invalid.";
 
@@ -862,7 +862,7 @@ QString
 Sequence::insertMonomerAt(const Monomer &monomer, std::size_t index)
 {
   if(index > size())
-    qFatalStream() << "Programming error. Index is out of bounds:" << index;
+    qFatal() << "Programming error. Index is out of bounds:" << index;
   else if(index == size())
     return storeMonomer(std::make_shared<Monomer>(monomer));
   else
@@ -886,7 +886,7 @@ Sequence::removeMonomerAt(std::size_t index)
   //  qDebug() << "Asking to remove Monomer at index" << index;
 
   if(index >= size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   // Some controls are in order: we have to check that at index, there is
   // a MonomerSPtr that is present both in m_monomers and in
@@ -900,7 +900,7 @@ Sequence::removeMonomerAt(std::size_t index)
 
   QString uuid = getUuidForMonomer(monomer_sp);
   if(uuid.isEmpty())
-    qFatalStream()
+    qFatal()
       << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
   std::vector<UuidMonomerWPtrPair>::const_iterator the_iterator_cst =
@@ -913,7 +913,7 @@ Sequence::removeMonomerAt(std::size_t index)
                  });
 
   if(the_iterator_cst == m_uuidMonomerPairs.cend())
-    qFatalStream()
+    qFatal()
       << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
   m_uuidMonomerPairs.erase(the_iterator_cst);
@@ -943,7 +943,7 @@ Sequence::modifyMonomer(std::size_t index,
                         bool override)
 {
   if(index >= size())
-    qFatalStream() << "Programming error. Index is out of bounds.";
+    qFatal() << "Programming error. Index is out of bounds.";
 
   MonomerSPtr monomer_sp = getMonomerSPtrAt(index);
 
@@ -1399,7 +1399,7 @@ QString
 Sequence::storeMonomer(const MonomerSPtr &monomer_sp)
 {
   if(monomer_sp == nullptr)
-    qFatalStream() << "The provided MonomerSPtr is nullptr.";
+    qFatal() << "The provided MonomerSPtr is nullptr.";
 
   // qDebug() << "Right before storage, there are currently" <<
   // m_monomers.size()
@@ -1407,7 +1407,7 @@ Sequence::storeMonomer(const MonomerSPtr &monomer_sp)
 
   // Do not store an item twice.
   if(hasMonomer(monomer_sp) || !getUuidForMonomer(monomer_sp).isEmpty())
-    qFatalStream()
+    qFatal()
       << "It is prohibited to store the same MonomerCstSPtr more than once.";
 
   // Even if we get a ref to shared_ptr, the reference count increment will
@@ -1432,7 +1432,7 @@ QString
 Sequence::storeMonomer(const MonomerSPtr &monomer_sp, std::size_t index)
 {
   if(monomer_sp == nullptr)
-    qFatalStream() << "The provided MonomerSPtr is nullptr.";
+    qFatal() << "The provided MonomerSPtr is nullptr.";
 
   // qDebug() << "Right before storage, there are currently" <<
   // m_monomers.size()
@@ -1440,7 +1440,7 @@ Sequence::storeMonomer(const MonomerSPtr &monomer_sp, std::size_t index)
 
   // Do not store an item twice.
   if(hasMonomer(monomer_sp) || !getUuidForMonomer(monomer_sp).isEmpty())
-    qFatalStream()
+    qFatal()
       << "It is prohibited to store the same MonomerCstSPtr more than once.";
 
   // Even if we get a ref to shared_ptr, the reference count increment will
@@ -1464,7 +1464,7 @@ bool
 Sequence::hasMonomer(const MonomerSPtr &monomer_sp) const
 {
   if(monomer_sp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<MonomerSPtr>::const_iterator the_iterator_cst =
     std::find_if(m_monomers.cbegin(),
@@ -1491,7 +1491,7 @@ bool
 Sequence::hasUuid(const MonomerSPtr &monomer_sp) const
 {
   if(monomer_sp == nullptr)
-    qFatalStream() << "Pointer cannot be nullptr.";
+    qFatal() << "Pointer cannot be nullptr.";
 
   std::vector<UuidMonomerWPtrPair>::const_iterator the_iterator_cst =
     std::find_if(m_uuidMonomerPairs.cbegin(),
@@ -1505,7 +1505,7 @@ Sequence::hasUuid(const MonomerSPtr &monomer_sp) const
 
   // Sanity check
   if(!hasMonomer(monomer_sp))
-    qFatalStream()
+    qFatal()
       << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
   return true;
@@ -1539,7 +1539,7 @@ Sequence::getMonomerForUuid(const QString &uuid) const
   // Sanity check
 
   if(!hasMonomer(monomer_csp))
-    qFatalStream()
+    qFatal()
       << "Inconsistency between m_monomers and m_uuidMonomerPairs.";
 
   // qDebug() << "Found Monomer:" << monomer_csp->getCode()
@@ -1558,7 +1558,7 @@ QString
 Sequence::getUuidForMonomer(const MonomerSPtr &monomer_sp) const
 {
   if(monomer_sp == nullptr)
-    qFatalStream() << "Programming error. Pointer cannot be nullptr.";
+    qFatal() << "Programming error. Pointer cannot be nullptr.";
 
   std::vector<UuidMonomerWPtrPair>::const_iterator the_iterator_cst =
     std::find_if(m_uuidMonomerPairs.cbegin(),
@@ -1573,7 +1573,7 @@ Sequence::getUuidForMonomer(const MonomerSPtr &monomer_sp) const
     {
       // Sanity check
       if(hasMonomer(monomer_sp))
-        qFatalStream() << "Inconsistency between the m_monomers and the "
+        qFatal() << "Inconsistency between the m_monomers and the "
                           "m_uuidMonomerPairs vectors.";
 
       return QString();
@@ -1581,7 +1581,7 @@ Sequence::getUuidForMonomer(const MonomerSPtr &monomer_sp) const
 
   // Sanity check
   if(!hasMonomer(monomer_sp))
-    qFatalStream() << "Inconsistency between the m_monomers and the "
+    qFatal() << "Inconsistency between the m_monomers and the "
                       "m_uuidMonomerPairs vectors.";
 
   return (*the_iterator_cst).first;
@@ -1603,7 +1603,7 @@ Sequence::getAllMonomerUuids() const
 
   // Sanity check
   if(the_uuid_strings.size() != m_monomers.size())
-    qFatalStream()
+    qFatal()
       << "Inconsistency between the <object>_s and <uuid-object> pairs.";
 
   return the_uuid_strings;
