@@ -55,11 +55,53 @@ Tolerance::Tolerance(QObject *parent): QObject(parent)
 {
 }
 
+Tolerance::Tolerance(const QString &text, QObject *parent): QObject(parent)
+{
+  initialize(text, parent);
+}
+
 Tolerance::Tolerance(Tolerance::Type type, double nominal, QObject *parent)
   : QObject(parent), m_nominal(nominal), m_type(type)
 {
 }
 
+Tolerance::Tolerance(const Tolerance &other, QObject *parent)
+  : QObject(parent), m_nominal(other.m_nominal), m_type(other.m_type)
+{
+}
+
+void
+Tolerance::initialize(double nominal, Type type, QObject *parent)
+{
+  QObject::setParent(parent);
+
+  if(m_typeToStringMap.value(type).isEmpty())
+    qFatal() << "Programming error. This tolerance type is not known.";
+
+  m_nominal = nominal;
+  m_type    = type;
+
+  emit toleranceChangedSignal(
+    std::pair<double, Tolerance::Type>(m_nominal, m_type));
+}
+
+void
+Tolerance::initialize(const Tolerance &other, QObject *parent)
+{
+  initialize(other.m_nominal, other.m_type, parent);
+}
+
+void
+Tolerance::initialize(const QString &text, QObject *parent)
+{
+  QObject::setParent(parent);
+
+  QStringList string_list = text.split(" ");
+  bool ok;
+  m_nominal = string_list[0].toInt(&ok);
+  m_type    = getType(string_list[1]);
+}
+
 void
 Tolerance::setNominal(double nominal)
 {
@@ -85,6 +127,10 @@ Tolerance::setType(Type type)
   if(m_type == type)
     return;
 
+  QString type_string = m_typeToStringMap.value(type);
+  if(type_string.isEmpty())
+    qFatal() << "Programming error. This tolerance type value is not known.";
+
   m_type = type;
 
   emit typeChangedSignal();
@@ -95,20 +141,18 @@ Tolerance::setType(Type type)
 void
 Tolerance::setType(const QString &text)
 {
-  std::map<Type, QString>::const_iterator the_iterator_cst =
+  QMap<Type, QString>::const_iterator the_iterator_cst =
     std::find_if(m_typeToStringMap.cbegin(),
                  m_typeToStringMap.cend(),
-                 [&](const std::pair<Type, QString> &pair) {
-                   if(pair.second == text)
-                     return true;
-                   return false;
+                 [text](const QString &value) {
+                   return value == text;
                  });
 
-  if(the_iterator_cst != m_typeToStringMap.cend())
-    m_type = (*the_iterator_cst).first;
-  else
-    qFatalStream()
-      << "Programming error. Tolerance type as string is not known.";
+  if(the_iterator_cst == m_typeToStringMap.cend())
+    qFatal() << "Programming error. This tolerance type string is not known:"
+             << text;
+
+  m_type = the_iterator_cst.key();
 
   emit typeChangedSignal();
   emit toleranceChangedSignal(
@@ -124,53 +168,32 @@ Tolerance::getType() const
 Tolerance::Type
 Tolerance::getType(const QString &text) const
 {
-  std::map<Type, QString>::const_iterator the_iterator_cst =
+  QMap<Type, QString>::const_iterator the_iterator_cst =
     std::find_if(m_typeToStringMap.cbegin(),
                  m_typeToStringMap.cend(),
-                 [&](const std::pair<Type, QString> &pair) {
-                   if(pair.second == text)
-                     return true;
-                   return false;
+                 [text](const QString &value) {
+                   return value == text;
                  });
 
-  if(the_iterator_cst != m_typeToStringMap.cend())
-    return (*the_iterator_cst).first;
+  if(the_iterator_cst == m_typeToStringMap.cend())
+    {
+      qDebug() << "Programming error. This tolerance string is not known.";
+      return Tolerance::Type::NOT_SET;
+    }
 
-  return Tolerance::Type::NOT_SET;
+  return the_iterator_cst.key();
+}
+
+QString
+Tolerance::getTypeAsString(Tolerance::Type type) const
+{
+  return m_typeToStringMap.value(type);
 }
 
 QString
 Tolerance::getTypeAsString() const
 {
-  std::map<Type, QString>::const_iterator the_iterator_cst =
-    std::find_if(m_typeToStringMap.cbegin(),
-                 m_typeToStringMap.cend(),
-                 [&](const std::pair<Type, QString> &pair) {
-                   if(pair.first == m_type)
-                     return true;
-                   return false;
-                 });
-
-  if(the_iterator_cst != m_typeToStringMap.cend())
-    return (*the_iterator_cst).second;
-
-  return QString();
-}
-
-void
-Tolerance::initialize(double nominal, Type type)
-{
-  m_nominal = nominal;
-  m_type    = type;
-
-  emit toleranceChangedSignal(
-    std::pair<double, Tolerance::Type>(m_nominal, m_type));
-}
-
-void
-Tolerance::initialize(const Tolerance &tolerance)
-{
-  initialize(tolerance.m_nominal, tolerance.m_type);
+  return getTypeAsString(m_type);
 }
 
 Tolerance *
@@ -190,15 +213,36 @@ Tolerance::calculateWidth(double reason) const
   else if(m_type == Type::RES)
     width = reason / m_nominal;
   else if(m_type == Type::PPM)
-    width = reason / 1000000 * m_nominal;
+    width = (m_nominal * reason) / 1000000;
   else
-    qFatalStream() << "Programming error. The Type is not valid.";
-
-  emit widthChangedSignal(width);
+    qFatal() << "Programming error. The Type is not valid.";
 
   return width;
 }
 
+double
+Tolerance::calculateHalfWidth(double reason) const
+{
+  return calculateWidth(reason) / 2;
+}
+
+double
+Tolerance::calculateNominal(double width, double mass_or_mz) const
+{
+  double nominal = 0;
+
+  if(m_type == Type::DALTON)
+    nominal = width;
+  else if(m_type == Type::RES)
+    nominal = mass_or_mz / width;
+  else if(m_type == Type::PPM)
+    nominal = width * 1000000 / mass_or_mz;
+  else
+    qFatal() << "Programming error. The Type is not valid.";
+
+  return nominal;
+}
+
 QString
 Tolerance::toString() const
 {
