@@ -128,7 +128,7 @@ Utils::~Utils()
 
 /*!
 \brief Configures the format of all the messages that are output using qDebug(),
-qDebug(), qDebug(), qFatalStream() and qDebug() using a number of
+qDebug(), qDebug(), qFatal() and qDebug() using a number of
 parameters.
 
 \list
