@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -41,14 +41,13 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace MsXpS
 {
 namespace libXpertMassGui
 {
 
 
-class DECLSPEC ScriptingHistoryListWidget : public QListWidget
+class DECLSPEC ScriptingHistoryListWidget: public QListWidget
 {
   Q_OBJECT
   public:
@@ -62,7 +61,8 @@ class DECLSPEC ScriptingHistoryListWidget : public QListWidget
   void keyPressEvent(QKeyEvent *event);
 
   signals:
-  void setSelectedItemsTextToScriptInput(const QString &code_text, bool overwrite);
+  void setSelectedItemsTextToScriptInput(const QString &code_text,
+                                         bool overwrite);
 
   public slots:
   void showAll();
@@ -80,5 +80,5 @@ class DECLSPEC ScriptingHistoryListWidget : public QListWidget
   void selectItemIndices(int startIndex, int endIndex);
 };
 
-} // namespace  minexpert
+} // namespace libXpertMassGui
 } // namespace MsXpS
