@@ -124,7 +124,7 @@ ActionId
 ActionId::fromString(const QString &text)
 {
   QStringList string_list = text.split('|');
-  qDebug() << "The string_list has size:" << string_list.size();
+  // qDebug() << "The string_list has size:" << string_list.size();
   Q_ASSERT(string_list.size() == 4);
 
   return ActionId(
@@ -230,8 +230,8 @@ ActionManager::installAction(const ActionId &action_id,
   // The member m_actions container contains an item that matches action_id. All
   // we have to do is return the corresponding QAction.
 
-  qDebug().noquote() << "Installing action: " << action_id.toString()
-                     << " with shortcut sequence: " << key_sequence;
+  // qDebug().noquote() << "Installing action: " << action_id.toString()
+  //                    << " with shortcut sequence: " << key_sequence;
 
   // The key_sequence argument contains the QKeySequence to be used as the
   // shortcut for the action. If that key_sequence is already used in any
@@ -252,13 +252,13 @@ ActionManager::installAction(const ActionId &action_id,
       foreach(auto pair, conflicting_items)
         text += QString("%1\n").arg(pair.first.toString());
 
-      qDebug().noquote() << "The conflicting items for shortcut: "
-                         << key_sequence << " are: " << text;
+      // qDebug().noquote() << "The conflicting items for shortcut: "
+      //                    << key_sequence << " are: " << text;
     }
   else
     {
-      qDebug() << "No conflicting items for key sequence"
-               << key_sequence.toString();
+      // qDebug() << "No conflicting items for key sequence"
+      //          << key_sequence.toString();
     }
 
   // Check if there is a m_actions item that matches action_id.
@@ -310,14 +310,14 @@ ActionManager::installAction(const ActionId &action_id,
         }
 #endif
 
-      qDebug() << "Returning action found:" << action_p->text()
-               << action_p->shortcut();
+      // qDebug() << "Returning action found:" << action_p->text()
+      //          << action_p->shortcut();
 
       return action_p;
     }
 
   // Since no QAction was found by action_id, we allocate a new one
-  // and to it as shortcut corresponding to key_sequence.
+  // and to it a shortcut corresponding to key_sequence.
 
   // We do not parent the action because Application::~Application will destroy
   // them. Also, set the label to the action, with the shortcut text associated
@@ -332,8 +332,8 @@ ActionManager::installAction(const ActionId &action_id,
   // Now that we have the new QAction, set it to the container.
   m_actions[action_id] = action_p;
 
-  qDebug() << "Installed new action:" << action_id.toString() << "-->"
-           << action_p->text() << "shortcut:" << action_p->shortcut();
+  // qDebug() << "Installed new action:" << action_id.toString() << "-->"
+  //          << action_p->text() << "shortcut:" << action_p->shortcut();
 
   return action_p;
 }
