@@ -291,7 +291,8 @@ IsotopicDataTableViewModel::data(const QModelIndex &index, int role) const
         {
           value_string = isotope_qsp->getName();
         }
-      else if(column == static_cast<int>(libXpertMassCore::IsotopeFields::SYMBOL))
+      else if(column ==
+              static_cast<int>(libXpertMassCore::IsotopeFields::SYMBOL))
         {
           value_string = isotope_qsp->getSymbol();
         }
@@ -377,7 +378,8 @@ IsotopicDataTableViewModel::setData(const QModelIndex &index,
 
       new_isotope_sp->setMass(new_value);
     }
-  else if(column == static_cast<int>(libXpertMassCore::IsotopeFields::PROBABILITY))
+  else if(column ==
+          static_cast<int>(libXpertMassCore::IsotopeFields::PROBABILITY))
     {
       double new_value = value.toDouble(&ok);
       if(!ok)
