@@ -82,7 +82,7 @@ JavaScriptingGuiUtils::print(const QString &text)
   //}
 
   if(mp_javaScriptingWnd == nullptr)
-    qFatalStream() << "Programming error. The pointer cannot be nullptr.";
+    qFatal() << "Programming error. The pointer cannot be nullptr.";
 
   mp_javaScriptingWnd->logOutTextEdit(text + "\n");
 }
