@@ -58,7 +58,6 @@
 #include "MsXpS/libXpertMassGui/JavaScriptingWnd.hpp"
 #include "MsXpS/libXpertMassGui/JavaScriptWorker.hpp"
 #include "MsXpS/libXpertMassGui/ScriptingHistoryListWidget.hpp"
-#include "MsXpS/libXpertMassGui/ScriptingObjectTreeWidgetItem.hpp"
 
 #include "ui_JavaScriptingWnd.h"
 
@@ -87,7 +86,7 @@ JavaScriptingWnd::JavaScriptingWnd(const QString &application_name,
 
 JavaScriptingWnd::~JavaScriptingWnd()
 {
-  // qDebug() << "Destructing...";
+  // qDebug() << "Destructing... with window visible:" << isVisible();
 
   writeSettings();
 }
@@ -95,16 +94,71 @@ JavaScriptingWnd::~JavaScriptingWnd()
 void
 JavaScriptingWnd::closeEvent(QCloseEvent *event)
 {
-  qDebug() << "Closing...";
+  // qDebug() << "Closing... with window visible:" << isVisible();
 
   writeSettings();
   event->accept();
 }
 
+void
+JavaScriptingWnd::writeSettings()
+{
+  QSettings settings(MsXpS::libXpertMassCore::Utils::configSettingsFilePath,
+                     QSettings::IniFormat);
+
+  // qDebug() << "Writing settings to file:"
+  // << MsXpS::libXpertMassCore::Utils::configSettingsFilePath;
+
+  settings.beginGroup("JavaScriptingWnd");
+
+  settings.setValue("geometry", saveGeometry());
+  settings.setValue("windowState", saveState());
+
+  // Colors
+
+  // qDebug() << __FILE__ << __LINE__
+  //<< "Setting m_successColor:" << m_successColor;
+
+  settings.setValue("successColor", m_successColor);
+  settings.setValue("undefinedColor", m_undefinedColor);
+  settings.setValue("failureColor", m_failureColor);
+  settings.setValue("commentColor", m_commentColor);
+  settings.setValue("jsInputColor", m_jsInputColor);
+
+  // Splitters
+  settings.setValue("treeSplitter", mp_ui->treeSplitter->saveState());
+  settings.setValue("historySplitter", mp_ui->treeSplitter->saveState());
+  settings.setValue("scriptingSplitter", mp_ui->scriptingSplitter->saveState());
+  settings.setValue("generalConfigSplitter",
+                    mp_ui->generalConfigSplitter->saveState());
+  settings.setValue("scriptingConfigSplitter",
+                    mp_ui->scriptingConfigSplitter->saveState());
+
+  // History
+  settings.setValue("history", historyAsStringList(true));
+  settings.setValue("historyLoggingType", m_historyLoggingType);
+
+  // Visibility
+  // The settings are only written when the window is either closed
+  // or destroyed (the window should thus be marked invisible).
+
+  // qDebug() << "Writing settings... with window visible:" << isVisible();
+
+  settings.setValue("visible", isVisible());
+
+  settings.endGroup();
+
+  settings.sync();
+}
+
 void
 JavaScriptingWnd::readSettings()
 {
-  QSettings settings;
+  QSettings settings(MsXpS::libXpertMassCore::Utils::configSettingsFilePath,
+                     QSettings::IniFormat);
+
+  // qDebug() << "Reading settings from file:"
+  //          << MsXpS::libXpertMassCore::Utils::configSettingsFilePath;
 
   settings.beginGroup("JavaScriptingWnd");
 
@@ -181,48 +235,9 @@ JavaScriptingWnd::readSettings()
   bool wasVisible = settings.value("visible").toBool();
   setVisible(wasVisible);
 
-  settings.endGroup();
-}
-
-void
-JavaScriptingWnd::writeSettings()
-{
-  QSettings settings;
-  settings.beginGroup("JavaScriptingWnd");
-
-  settings.setValue("geometry", saveGeometry());
-  settings.setValue("windowState", saveState());
-
-  // Colors
-
-  // qDebug() << __FILE__ << __LINE__
-  //<< "Setting m_successColor:" << m_successColor;
-
-  settings.setValue("successColor", m_successColor);
-  settings.setValue("undefinedColor", m_undefinedColor);
-  settings.setValue("failureColor", m_failureColor);
-  settings.setValue("commentColor", m_commentColor);
-  settings.setValue("jsInputColor", m_jsInputColor);
-
-  // Splitters
-  settings.setValue("treeSplitter", mp_ui->treeSplitter->saveState());
-  settings.setValue("historySplitter", mp_ui->treeSplitter->saveState());
-  settings.setValue("scriptingSplitter", mp_ui->scriptingSplitter->saveState());
-  settings.setValue("generalConfigSplitter",
-                    mp_ui->generalConfigSplitter->saveState());
-  settings.setValue("scriptingConfigSplitter",
-                    mp_ui->scriptingConfigSplitter->saveState());
-
-  // History
-  settings.setValue("history", historyAsStringList(true));
-  settings.setValue("historyLoggingType", m_historyLoggingType);
-
-  // Visibility
-  settings.setValue("visible", isVisible());
+  // qDebug() << "The window was visible?" << wasVisible;
 
   settings.endGroup();
-
-  settings.sync();
 }
 
 void
@@ -356,10 +371,6 @@ JavaScriptingWnd::initialize()
 
   mp_fileMenu->addAction(mp_loadScriptFileAct);
 
-  /// We'll need these strings many times.
-  QString result;
-  QString help;
-
   mp_ui->jsReferenceTextTabWidget->setMovable(true);
 
   // Register the JS reference texts for this
@@ -370,8 +381,6 @@ JavaScriptingWnd::initialize()
 
   initializeJsEngine(mp_scriptingEnvironment->getJsEngine());
 
-  show();
-
   readSettings();
 }
 
@@ -396,8 +405,8 @@ JavaScriptingWnd::hide()
 void
 JavaScriptingWnd::registerKnownJsReferenceTexts()
 {
-  // The JS reference text exist as two files in the doc/js_reference directory
-  // and are made available as Qt resources.
+  // The JS reference text exist as a number of files in the doc/js_reference
+  // directory and are made available as Qt resources.
 
 #if 0
 // Debugging code to list all the resources visible from here.
@@ -415,6 +424,27 @@ QDir resourceDir(":/");
     }
 #endif
 
+
+  ////////////////// generalities about JavaScript ///////////////////
+
+  QFile jsGeneralitiesTextFile(":/core/js_generalities_text.txt");
+  QString jsGeneralitiesText;
+
+  if(!jsGeneralitiesTextFile.open(QFile::ReadOnly | QFile::Text))
+    {
+      qDebug() << "Attention JavaScript generalities text not available:"
+               << jsGeneralitiesTextFile.errorString();
+    }
+  else
+    {
+      jsGeneralitiesText = jsGeneralitiesTextFile.readAll();
+      registerJsReferenceText("Generalities", jsGeneralitiesText);
+
+      // qDebug() << "The JS generalities text has size"
+      //          << m_jsRefLabelRefTextMap.value("Generalities").size();
+    }
+
+
   //////////////////// pappsomspp core and widget ////////////////////
 
   QFile jsClassRefPappsomsppCoreTextFile(
@@ -424,19 +454,18 @@ QDir resourceDir(":/");
 
   if(!jsClassRefPappsomsppCoreTextFile.open(QFile::ReadOnly | QFile::Text))
     {
-      qCritical()
-        << "Attention JavaScript class reference text not available for "
-           "libpappsomspp Core:"
-        << jsClassRefPappsomsppCoreTextFile.errorString();
+      qDebug() << "Attention JavaScript class reference text not available for "
+                  "libPappsomsppCore:"
+               << jsClassRefPappsomsppCoreTextFile.errorString();
     }
   else
     {
       jsClassRefPappsomsppCoreText = jsClassRefPappsomsppCoreTextFile.readAll();
-      m_jsRefLabelRefTextMap["libPappsomsppCore"] =
-        jsClassRefPappsomsppCoreText;
+      registerJsReferenceText("libPappsomsppCore",
+                              jsClassRefPappsomsppCoreText);
 
-      qDebug() << "The libPappsomsppCore reference text has size"
-               << m_jsRefLabelRefTextMap.value("libPappsomsppCore").size();
+      // qDebug() << "The libPappsomsppCore reference text has size"
+      //          << m_jsRefLabelRefTextMap.value("libPappsomsppCore").size();
     }
 
   // Note that this one will only be available when the program that uses this
@@ -450,18 +479,17 @@ QDir resourceDir(":/");
 
   if(!jsClassRefPappsomsppGuiTextFile.open(QFile::ReadOnly | QFile::Text))
     {
-      qCritical()
-        << "Attention JavaScript class reference text not available for "
-           "libpappsomspp Gui:"
-        << jsClassRefPappsomsppGuiTextFile.errorString();
+      qDebug() << "Attention JavaScript class reference text not available for "
+                  "libPappsomsppGui:"
+               << jsClassRefPappsomsppGuiTextFile.errorString();
     }
   else
     {
       jsClassRefPappsomsppGuiText = jsClassRefPappsomsppGuiTextFile.readAll();
-      m_jsRefLabelRefTextMap["libPappsomsppGui"] = jsClassRefPappsomsppGuiText;
+      registerJsReferenceText("libPappsomsppGui", jsClassRefPappsomsppGuiText);
 
-      qDebug() << "The libPappsomsppGui reference text has size"
-               << m_jsRefLabelRefTextMap.value("libPappsomsppGui").size();
+      // qDebug() << "The libPappsomsppGui reference text has size"
+      //          << m_jsRefLabelRefTextMap.value("libPappsomsppGui").size();
     }
 
 
@@ -473,18 +501,17 @@ QDir resourceDir(":/");
 
   if(!jsClassRefXpertMassTextFile.open(QFile::ReadOnly | QFile::Text))
     {
-      qCritical()
-        << "Attention JavaScript class reference text not available for "
-           "libXpertMassCore:"
-        << jsClassRefXpertMassTextFile.errorString();
+      qDebug() << "Attention JavaScript class reference text not available for "
+                  "libXpertMassCore:"
+               << jsClassRefXpertMassTextFile.errorString();
     }
   else
     {
       jsClassRefXpertMassText = jsClassRefXpertMassTextFile.readAll();
-      m_jsRefLabelRefTextMap["libXpertMassCore"] = jsClassRefXpertMassText;
+      registerJsReferenceText("libXpertMassCore", jsClassRefXpertMassText);
 
-      qDebug() << "The libXpertMass reference text has size"
-               << m_jsRefLabelRefTextMap.value("libXpertMass").size();
+      // qDebug() << "The libXpertMassCore reference text has size"
+      //          << m_jsRefLabelRefTextMap.value("libXpertMassCore ").size();
     }
 
   QFile jsClassRefXpertMassGuiTextFile(":/gui/class_js_reference_text.txt");
@@ -493,18 +520,17 @@ QDir resourceDir(":/");
 
   if(!jsClassRefXpertMassGuiTextFile.open(QFile::ReadOnly | QFile::Text))
     {
-      qCritical()
-        << "Attention JavaScript class reference text not available for "
-           "libXpertMassGui:"
-        << jsClassRefXpertMassGuiTextFile.errorString();
+      qDebug() << "Attention JavaScript class reference text not available for "
+                  "libXpertMassGui:"
+               << jsClassRefXpertMassGuiTextFile.errorString();
     }
   else
     {
       jsClassRefXpertMassGuiText = jsClassRefXpertMassGuiTextFile.readAll();
-      m_jsRefLabelRefTextMap["libXpertMassGui"] = jsClassRefXpertMassGuiText;
+      registerJsReferenceText("libXpertMassGui", jsClassRefXpertMassGuiText);
 
-      qDebug() << "The libXpertMassGui reference text has size"
-               << m_jsRefLabelRefTextMap.value("libXpertMassGui").size();
+      // qDebug() << "The libXpertMassGui reference text has size"
+      //          << m_jsRefLabelRefTextMap.value("libXpertMassGui").size();
     }
 }
 
@@ -513,10 +539,12 @@ JavaScriptingWnd::registerJsReferenceText(const QString &label,
                                           const QString &text)
 {
   if(m_jsRefLabelRefTextMap.contains(label))
-    qWarning() << "A map entry with same" << label
-               << "key is there already. Erasing it.";
+    qDebug() << "A map entry with same" << label
+             << "key is there already. Erasing it.";
 
   m_jsRefLabelRefTextMap[label] = text;
+
+  // qDebug() << "Registered JS reference text for" << label;
 }
 
 void
@@ -527,14 +555,16 @@ JavaScriptingWnd::displayMappedJsRefTextToTab(const QString &label)
 
   if(!m_jsRefLabelRefTextMap.contains(label))
     {
-      qCritical() << "The map does not contain any such key:" << label
-                  << "Please first addLabelledJsReferenceText().";
+      qDebug() << "The map does not contain any such key:" << label
+               << "Please first addLabelledJsReferenceText().";
       return;
     }
 
   QTabWidget *js_reference_text_tab_widget_p = mp_ui->jsReferenceTextTabWidget;
-  qDebug() << "The js reference tab widget has "
-           << js_reference_text_tab_widget_p->count() << "pages";
+
+  // qDebug() << "Before displaying JS reference text for" << label
+  //          << ", the js reference tab widget has "
+  //          << js_reference_text_tab_widget_p->count() << "pages";
 
   QWidget *new_widget_p      = new QWidget();
   QVBoxLayout *page_layout_p = new QVBoxLayout(new_widget_p);
@@ -546,8 +576,8 @@ JavaScriptingWnd::displayMappedJsRefTextToTab(const QString &label)
 
   js_reference_text_tab_widget_p->addTab(new_widget_p, label);
 
-  qDebug() << "The js reference tab widget has now"
-           << js_reference_text_tab_widget_p->count() << "pages";
+  // qDebug() << "And now, the js reference tab widget has"
+  //          << js_reference_text_tab_widget_p->count() << "pages";
 }
 
 void
@@ -558,24 +588,31 @@ JavaScriptingWnd::displayAllMappedJsRefTextsToTabs()
 
   QTabWidget *js_reference_text_tab_widget_p = mp_ui->jsReferenceTextTabWidget;
 
-  qDebug() << "The js reference tab widget has "
-           << js_reference_text_tab_widget_p->count() << "pages";
+  // qDebug() << "The js reference tab widget has "
+  //          << js_reference_text_tab_widget_p->count() << "tab pages";
 
+  // The foreach() in QMap iterates over the values by default.
   foreach(const QString &label, m_jsRefLabelRefTextMap.keys())
     {
+      QString reference_text = m_jsRefLabelRefTextMap.value(label);
+
+      // qDebug() << "Now handling the JS reference text for" << label
+      //          << "with text:" << reference_text;
+
       QWidget *new_widget_p      = new QWidget();
       QVBoxLayout *page_layout_p = new QVBoxLayout(new_widget_p);
       page_layout_p->setContentsMargins(0, 0, 0, 0);
+
       QPlainTextEdit *text_edit_widget_p = new QPlainTextEdit();
       text_edit_widget_p->setObjectName("plain_text_edit");
-      text_edit_widget_p->setPlainText(m_jsRefLabelRefTextMap.value(label));
+      text_edit_widget_p->setPlainText(reference_text);
       page_layout_p->addWidget(text_edit_widget_p);
 
       js_reference_text_tab_widget_p->addTab(new_widget_p, label);
     }
 
-  qDebug() << "The js reference tab widget has now"
-           << js_reference_text_tab_widget_p->count() << "pages";
+  // qDebug() << "The js reference tab widget has now"
+  //          << js_reference_text_tab_widget_p->count() << "tab pages";
 }
 
 void
@@ -699,7 +736,7 @@ JavaScriptingWnd::regexFilterJsReferenceText(const QString &input_text,
 
           // The position of the context line, either upstream or downstream of
           // the matched line.
-          int pos = 0;
+          int pos;
 
           if(contextLines > 0)
             {
@@ -818,16 +855,14 @@ JavaScriptingWnd::verbatimFilterJsReferenceText(const QString &input_text,
 
           // Handle the context lines insertion upstream of the matched line.
 
-          // The position of the context line, either upstream or downstream of
-          // the matched line.
-          int pos = 0;
-
           if(contextLines > 0)
             {
               // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
               //<< "Handling upstream text";
 
-              for(pos = contextLines; pos > 0; --pos)
+              // pos: the position of the context line, either upstream or
+              // downstream of the matched line.
+              for(int pos = contextLines; pos > 0; --pos)
                 {
                   newIdx = iter - pos;
 
@@ -863,7 +898,9 @@ JavaScriptingWnd::verbatimFilterJsReferenceText(const QString &input_text,
               // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
               //<< "Handling downstream text";
 
-              for(pos = 1; pos <= contextLines; ++pos)
+              // pos: the position of the context line, either upstream or
+              // downstream of the matched line.
+              for(int pos = 1; pos <= contextLines; ++pos)
                 {
                   newIdx = iter + pos;
 
@@ -1346,7 +1383,7 @@ JavaScriptingWnd::restoreHistory(QSettings &settings)
   QProgressDialog *progress_dialog_p = new QProgressDialog(this, Qt::Dialog);
   progress_dialog_p->setLabelText("Importing scripting history");
   progress_dialog_p->setMaximum(wholeHistoryAsListOfStrings.size());
-  connect(progress_dialog_p, &QProgressDialog::canceled, [this]() {
+  connect(progress_dialog_p, &QProgressDialog::canceled, this, [&]() {
     m_shouldHistoryLoadCancel = true;
   });
 
@@ -1437,7 +1474,9 @@ JavaScriptingWnd::resetHistory()
 void
 JavaScriptingWnd::saveHistory()
 {
-  QSettings settings;
+  QSettings settings(MsXpS::libXpertMassCore::Utils::configSettingsFilePath,
+                     QSettings::IniFormat);
+
   settings.beginGroup("JavaScriptingWnd");
 
   // History
@@ -1490,11 +1529,10 @@ JavaScriptingWnd::loadScriptFile(const QString &fileName)
       fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
       fileDialog.setDirectory(QDir::home());
 
-      QStringList fileNames;
-
       if(fileDialog.exec())
         {
-          scriptFileName = fileDialog.selectedFiles().first();
+          QStringList selected_files = fileDialog.selectedFiles();
+          scriptFileName             = selected_files.first();
         }
       else
         return;
@@ -1567,20 +1605,20 @@ JavaScriptingWnd::feedBackForExposedQObject(const QString &object_name,
   QTextCharFormat boldFormat;
   boldFormat.setFontWeight(QFont::Bold);
   QTextCharFormat normalFormat;
-  boldFormat.setFontWeight(QFont::Normal);
+  normalFormat.setFontWeight(QFont::Normal);
 
-  // Insert bold text
+  // Insert the object description first
+  cursor.insertText(QString("%1:\n").arg(object_description), normalFormat);
+
+  // Insert the object name, and may also the alias
   cursor.insertText(object_name, boldFormat);
 
   if(!object_alias.isEmpty())
     {
       cursor.insertText(" aliased as ", normalFormat);
-      cursor.insertText(QString("%1").arg(object_alias), normalFormat);
+      cursor.insertText(QString("%1").arg(object_alias), boldFormat);
     }
 
-  // Insert normal text after
-  cursor.insertText("\n");
-  cursor.insertText(object_description, normalFormat);
   cursor.insertText("\n\n");
 }
 
@@ -1592,9 +1630,6 @@ JavaScriptingWnd::logHistory(const QString &text, LogTextColor textColor)
   //          << "; with last index:" << m_lastHistoryIndex
   //          << "with color:" << m_logTextColorMap[textColor];
 
-  // Make a copy because we'll modify it.
-  QString localText = text;
-
   // Allocate a new item that is automatically set to the list widget.
   QListWidgetItem *item = new QListWidgetItem(mp_ui->historyListWidget);
   QFont font(item->font());
@@ -1620,7 +1655,6 @@ JavaScriptingWnd::logHistory(const QString &text, LogTextColor textColor)
   mp_ui->historyListWidget->setCurrentRow(m_lastHistoryIndex - 1,
                                           QItemSelectionModel::Deselect);
 
-
   // We need to set that last index value to count() here, because
   // the call to setCurrentRow triggers updating of that index to
   // the (m_lastHistoryIndex - 1) value (see signal connection to
@@ -1661,7 +1695,7 @@ JavaScriptingWnd::removeColorTag(QString &text, LogTextColor &color)
   // string. We return false if the color tag was not there or if the value
   // was not convertible to int.
 
-  QRegularExpression colorTagRegexp("<color>(\\d+)</color>");
+  static QRegularExpression colorTagRegexp("<color>(\\d+)</color>");
 
   QRegularExpressionMatch match = colorTagRegexp.match(text);
 
@@ -1694,7 +1728,7 @@ JavaScriptingWnd::removeColorTag(QString &text, LogTextColor &color)
 void
 JavaScriptingWnd::runScript(const QString &code_text, const QString &comment)
 {
-  qDebug() << "20251007-Running script";
+  // qDebug() << "Running script";
 
   // We want to run the script in its own thread. For this, the QJSEngine
   // that will evaluate the script NEEDS to have been allocated IN THAT THREAD.
@@ -1739,14 +1773,14 @@ JavaScriptingWnd::runScript(const QString &code_text, const QString &comment)
 void
 JavaScriptingWnd::scriptHasFinishedRunning(QJSValue value)
 {
-  qDebug() << "20251007-The script has finished running.";
+  // qDebug() << "The script has finished running.";
 
   // If there is an explanatory comment to this script command, then start
   // by logging it, so that it precedes the result output in the
   // logOutTextEdit widget.
 
   if(!m_scriptComment.isEmpty())
-    logOutTextEdit(QString("%1%2").arg(m_commentPrefix).arg(m_scriptComment),
+    logOutTextEdit(QString("%1%2").arg(m_commentPrefix, m_scriptComment),
                    LogTextColor::Comment);
 
   QStringList script_as_lines = m_scriptText.split("\n");
@@ -1793,18 +1827,16 @@ JavaScriptingWnd::scriptHasFinishedRunning(QJSValue value)
         }
     }
 
-  qDebug() << "20251007-The result is:" << value.toString();
-
-  QString error_details;
+  // qDebug() << "The result is:" << value.toString();
 
   if(value.isError())
     {
-      error_details = QString("Name: %1\nMessage: %2\nStack: %3\n")
-                        .arg(value.property("name").toString())
-                        .arg(value.property("message").toString())
-                        .arg(value.property("stack").toString());
+      QString error_details = QString("Name: %1\nMessage: %2\nStack: %3\n")
+                                .arg(value.property("name").toString(),
+                                     value.property("message").toString(),
+                                     value.property("stack").toString());
 
-      qDebug() << "Error details:" << error_details;
+      // qDebug() << "Error details:" << error_details;
     }
 
   // When a command has been run, whatever its result, we remove it from the
