@@ -154,7 +154,7 @@ MassPeakShaperConfigDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
 {
   // qDebug();
   writeSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 }
 
 /*!
@@ -165,7 +165,7 @@ MassPeakShaperConfigDlg::~MassPeakShaperConfigDlg()
   // qDebug();
 
   writeSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 }
 
 /*!
@@ -231,7 +231,7 @@ MassPeakShaperConfigDlg::setupDialog()
 
   v_box_layout_p->addWidget(mp_massPeakShaperConfigWidget);
 
-  mp_ui->peakShapeConfigFrame->setLayout(v_box_layout_p);
+  mp_ui->peakShaperConfigFrame->setLayout(v_box_layout_p);
 
   connect(mp_massPeakShaperConfigWidget,
           &MassPeakShaperConfigWidget::updatedMassPeakShaperConfigSignal,
@@ -245,7 +245,7 @@ MassPeakShaperConfigDlg::setupDialog()
   // The values above are actually set in readSettings (with default values if
   // missing in the config settings.)
   readSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 }
 
 void
@@ -279,7 +279,7 @@ MassPeakShaperConfigDlg::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning()
+      qDebug()
         << "Cannot register MassPeakShaperConfigDlg class: engine is null";
       return;
     }
