@@ -14,7 +14,7 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/SequenceRanges.hpp>
+#include "MsXpS/libXpertMassCore/SequenceRanges.hpp"
 
 
 namespace MsXpS
