@@ -21,9 +21,9 @@
 /////////////////////// Local includes
 #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/Polymer.hpp>
-#include <libXpertMass/CrossLink.hpp>
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Polymer.hpp"
+#include "MsXpS/libXpertMassCore/CrossLink.hpp"
 
 namespace MsXpS
 {
@@ -50,7 +50,7 @@ SCENARIO("Construction of a CrossLink", "[CrossLink]")
     "A Polymer is allocated as a SPtr and then the XML file is loaded from "
     "disk")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 240);
 
@@ -114,7 +114,7 @@ SCENARIO("Construction of a CrossLink and use with a Polymer", "[CrossLink]")
     "A Polymer is allocated as a SPtr and then the XML file is loaded from "
     "disk")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 240);
 
@@ -197,7 +197,7 @@ SCENARIO("Construction of a CrossLink and use with a Polymer", "[CrossLink]")
                         .toStdString() == ";66;67;68;");
 
               std::vector<std::size_t> extreme_locations =
-                cross_link_sp->locationssOfOnlyExtremeSequenceMonomers(
+                cross_link_sp->locationsOfOnlyExtremeSequenceMonomers(
                   Enums::LocationType::INDEX);
 
               REQUIRE(extreme_locations.front() == 66);
@@ -356,7 +356,7 @@ SCENARIO(
 
   GIVEN("A Polymer instance created by loading an XML file")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 352);
 
