@@ -14,8 +14,7 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/IndexRangeCollection.hpp>
-
+#include "MsXpS/libXpertMassCore/IndexRangeCollection.hpp"
 
 namespace MsXpS
 {
@@ -23,7 +22,8 @@ namespace libXpertMassCore
 {
 
 
-SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollection]")
+SCENARIO("Construction of a IndexRangeCollection instance",
+         "[IndexRangeCollection]")
 {
   QString index_range_string_1("[50-150]");
   IndexRange index_range_1(50, 150);
@@ -35,9 +35,9 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
   IndexRange index_range_3(30, 170);
 
   QString all_three_index_range_strings = QString("%1%2%3")
-                                               .arg(index_range_string_1)
-                                               .arg(index_range_string_2)
-                                               .arg(index_range_string_3);
+                                            .arg(index_range_string_1)
+                                            .arg(index_range_string_2)
+                                            .arg(index_range_string_3);
 
   GIVEN("Construction with no argument")
   {
@@ -55,10 +55,11 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
   }
 
   GIVEN(
-    "Construction of a IndexRangeCollection instance with a string representing "
-    "three IndexRange instances")
+    "Construction of a IndexRangeCollection instance with a string "
+    "representing three IndexRange instances of POSITION location type")
   {
-    IndexRangeCollection index_range_collection(all_three_index_range_strings);
+    IndexRangeCollection index_range_collection(all_three_index_range_strings,
+                                                Enums::LocationType::POSITION);
 
     THEN("The list must have size 3")
     {
@@ -66,23 +67,23 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
 
       AND_THEN("All the members of the list should have proper values")
       {
-        IndexRange first_index_range =
-          index_range_collection.getRangeCstRefAt(0);
+        IndexRange first_index_range(index_range_collection.getRangeCstRefAt(0),
+                                     Q_NULLPTR);
 
-        REQUIRE(first_index_range.start == index_range_1.start - 1);
-        REQUIRE(first_index_range.stop == index_range_1.stop - 1);
+        REQUIRE(first_index_range.m_start == index_range_1.m_start - 1);
+        REQUIRE(first_index_range.m_stop == index_range_1.m_stop - 1);
 
-        IndexRange second_index_range =
-          index_range_collection.getRangeCstRefAt(1);
+        IndexRange second_index_range(
+          index_range_collection.getRangeCstRefAt(1), Q_NULLPTR);
 
-        REQUIRE(second_index_range.start == index_range_2.start - 1);
-        REQUIRE(second_index_range.stop == index_range_2.stop - 1);
+        REQUIRE(second_index_range.m_start == index_range_2.m_start - 1);
+        REQUIRE(second_index_range.m_stop == index_range_2.m_stop - 1);
 
-        IndexRange third_index_range =
-          index_range_collection.getRangeCstRefAt(2);
+        IndexRange third_index_range(index_range_collection.getRangeCstRefAt(2),
+                                     Q_NULLPTR);
 
-        REQUIRE(third_index_range.start == index_range_3.start - 1);
-        REQUIRE(third_index_range.stop == index_range_3.stop - 1);
+        REQUIRE(third_index_range.m_start == index_range_3.m_start - 1);
+        REQUIRE(third_index_range.m_stop == index_range_3.m_stop - 1);
       }
     }
   }
@@ -96,7 +97,8 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
 
     WHEN("Constructing a IndexRangeCollection instance")
     {
-      IndexRangeCollection index_range_collection(all_three_index_range_strings);
+      IndexRangeCollection index_range_collection(
+        all_three_index_range_strings);
 
       THEN("The list is created empty")
       {
@@ -114,7 +116,8 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
 
     WHEN("Constructing a IndexRangeCollection instance")
     {
-      IndexRangeCollection index_range_collection(all_three_index_range_strings);
+      IndexRangeCollection index_range_collection(
+        all_three_index_range_strings);
 
       THEN("The list is created empty")
       {
@@ -132,7 +135,8 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
 
     WHEN("Constructing a IndexRangeCollection instance")
     {
-      IndexRangeCollection index_range_collection(all_three_index_range_strings);
+      IndexRangeCollection index_range_collection(
+        all_three_index_range_strings);
 
       THEN("The list is created empty")
       {
@@ -150,7 +154,8 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
 
     WHEN("Constructing a IndexRangeCollection instance")
     {
-      IndexRangeCollection index_range_collection(all_three_index_range_strings);
+      IndexRangeCollection index_range_collection(
+        all_three_index_range_strings);
 
       THEN("The list is created empty")
       {
@@ -186,55 +191,60 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
           "the list")
         {
           REQUIRE(index_range_collection.size() == 2);
-          REQUIRE(index_range_collection.getRangeCstRefAt(index_range_collection.size() -
-                                                   1) == index_range_2);
+          REQUIRE(index_range_collection.getRangeCstRefAt(
+                    index_range_collection.size() - 1) == index_range_2);
         }
 
         AND_WHEN(
-          "That 2-sized IndexRangeCollection instance is copied (copy-constructor "
+          "That 2-sized IndexRangeCollection instance is copied "
+          "(copy-constructor "
           "with reference)")
         {
-          IndexRangeCollection new_index_range_collection(index_range_collection);
+          IndexRangeCollection new_index_range_collection(
+            index_range_collection);
 
           THEN("The two IndexRangeCollection instances must have the same data")
           {
             REQUIRE(new_index_range_collection.getComment().toStdString() ==
                     index_range_collection.getComment().toStdString());
-            REQUIRE(new_index_range_collection.size() == index_range_collection.size());
+            REQUIRE(new_index_range_collection.size() ==
+                    index_range_collection.size());
             REQUIRE(new_index_range_collection.getRangeCstRefAt(0) ==
                     index_range_collection.getRangeCstRefAt(0));
-            REQUIRE(
-              new_index_range_collection.getRangeCstRefAt(new_index_range_collection.size() -
-                                                   1) ==
-              index_range_collection.getRangeCstRefAt(new_index_range_collection.size() - 1));
+            REQUIRE(new_index_range_collection.getRangeCstRefAt(
+                      new_index_range_collection.size() - 1) ==
+                    index_range_collection.getRangeCstRefAt(
+                      new_index_range_collection.size() - 1));
           }
         }
 
         AND_WHEN(
-          "That 2-sized IndexRangeCollection instance is copied (assignment "
-          "operator) to itself,  a reference to itself is returned")
+          "That 2-sized IndexRangeCollection instance is initialized to "
+          "itself,  a reference to itself is returned")
         {
-          REQUIRE((index_range_collection = index_range_collection) == index_range_collection);
+          REQUIRE((index_range_collection.initialize(index_range_collection)) ==
+                  index_range_collection);
         }
 
         AND_WHEN(
-          "That 2-sized IndexRangeCollection instance is copied (assignment "
-          "operator)")
+          "A new IndexRangeCollection instance is copy-constructed from the "
+          "previous one")
         {
-          IndexRangeCollection new_index_range_collection;
-          new_index_range_collection = index_range_collection;
+          IndexRangeCollection new_index_range_collection(
+            index_range_collection, Q_NULLPTR);
 
           THEN("The two IndexRangeCollection instances must have the same data")
           {
             REQUIRE(new_index_range_collection.getComment().toStdString() ==
                     index_range_collection.getComment().toStdString());
-            REQUIRE(new_index_range_collection.size() == index_range_collection.size());
+            REQUIRE(new_index_range_collection.size() ==
+                    index_range_collection.size());
             REQUIRE(new_index_range_collection.getRangeCstRefAt(0) ==
                     index_range_collection.getRangeCstRefAt(0));
-            REQUIRE(
-              new_index_range_collection.getRangeCstRefAt(new_index_range_collection.size() -
-                                                   1) ==
-              index_range_collection.getRangeCstRefAt(index_range_collection.size() - 1));
+            REQUIRE(new_index_range_collection.getRangeCstRefAt(
+                      new_index_range_collection.size() - 1) ==
+                    index_range_collection.getRangeCstRefAt(
+                      index_range_collection.size() - 1));
           }
         }
       }
@@ -243,7 +253,8 @@ SCENARIO("Construction of a IndexRangeCollection instance", "[IndexRangeCollecti
 }
 
 SCENARIO(
-  "Empty IndexRangeCollection instances can be filled-in after construction with "
+  "Empty IndexRangeCollection instances can be filled-in after construction "
+  "with "
   "other IndexRangeCollection",
   "[IndexRangeCollection]")
 {
@@ -263,8 +274,8 @@ SCENARIO(
 
     REQUIRE(index_range_collection_0.size() == 2);
     REQUIRE(index_range_collection_0.getRangeCstRefAt(0) == index_range_1);
-    REQUIRE(index_range_collection_0.getRangeCstRefAt(index_range_collection_0.size() - 1) ==
-            index_range_2);
+    REQUIRE(index_range_collection_0.getRangeCstRefAt(
+              index_range_collection_0.size() - 1) == index_range_2);
 
     AND_GIVEN("Construction of an empty IndexRangeCollection instance")
     {
@@ -274,19 +285,22 @@ SCENARIO(
       REQUIRE(index_range_collection.size() == 0);
 
       WHEN(
-        "The first IndexRangeCollection instance with two items is appended to the "
+        "The first IndexRangeCollection instance with two items is appended to "
+        "the "
         "the empty one")
       {
         index_range_collection.appendIndexRanges(index_range_collection_0);
 
         THEN("Its size must become the same at the one that was appended")
         {
-          REQUIRE(index_range_collection.size() == index_range_collection_0.size());
+          REQUIRE(index_range_collection.size() ==
+                  index_range_collection_0.size());
           REQUIRE(index_range_collection.getRangeCstRefAt(0) ==
                   index_range_collection_0.getRangeCstRefAt(0));
-          REQUIRE(
-            index_range_collection.getRangeCstRefAt(index_range_collection.size() - 1) ==
-            index_range_collection_0.getRangeCstRefAt(index_range_collection_0.size() - 1));
+          REQUIRE(index_range_collection.getRangeCstRefAt(
+                    index_range_collection.size() - 1) ==
+                  index_range_collection_0.getRangeCstRefAt(
+                    index_range_collection_0.size() - 1));
         }
 
         AND_WHEN("A new IndexRange instance is set (not appended)")
@@ -296,7 +310,8 @@ SCENARIO(
           THEN("The single instance has to be this last")
           {
             REQUIRE(index_range_collection.size() == 1);
-            REQUIRE(index_range_collection.getRangeCstRefAt(0) == index_range_3);
+            REQUIRE(index_range_collection.getRangeCstRefAt(0) ==
+                    index_range_3);
           }
 
           AND_WHEN("A IndexRangeCollection instance is set (not appended)")
@@ -310,10 +325,10 @@ SCENARIO(
               REQUIRE(index_range_collection.size() == 2);
               REQUIRE(index_range_collection.getRangeCstRefAt(0) ==
                       index_range_collection_0.getRangeCstRefAt(0));
-              REQUIRE(
-                index_range_collection.getRangeCstRefAt(index_range_collection.size() - 1) ==
-                index_range_collection_0.getRangeCstRefAt(index_range_collection_0.size() -
-                                                   1));
+              REQUIRE(index_range_collection.getRangeCstRefAt(
+                        index_range_collection.size() - 1) ==
+                      index_range_collection_0.getRangeCstRefAt(
+                        index_range_collection_0.size() - 1));
             }
           }
         }
@@ -323,7 +338,8 @@ SCENARIO(
 }
 
 SCENARIO(
-  "Empty IndexRangeCollection instances can be filled in after construction with "
+  "Empty IndexRangeCollection instances can be filled in after construction "
+  "with "
   "strings representative of IndexRange instances (single or multiple)",
   "[IndexRangeCollection]")
 {
@@ -337,9 +353,9 @@ SCENARIO(
   IndexRange index_range_3(30, 170);
 
   QString all_three_index_range_strings = QString("%1%2%3")
-                                               .arg(index_range_string_1)
-                                               .arg(index_range_string_2)
-                                               .arg(index_range_string_3);
+                                            .arg(index_range_string_1)
+                                            .arg(index_range_string_2)
+                                            .arg(index_range_string_3);
 
   GIVEN("Construction with a comment and no list; and IndexRange objects")
   {
@@ -349,10 +365,11 @@ SCENARIO(
     REQUIRE(index_range_collection.size() == 0);
 
     WHEN(
-      "That IndexRangeCollection is set with one string representative of a single "
-      "IndexRange instance")
+      "That IndexRangeCollection is set with one string representative of a "
+      "single IndexRange instance of location type INDEX")
     {
-      index_range_collection.setIndexRanges(index_range_string_1);
+      index_range_collection.setIndexRanges(index_range_string_1,
+                                            Enums::LocationType::INDEX);
 
       THEN(
         "The list must have size 1, and that object has to be the one set,  "
@@ -361,18 +378,41 @@ SCENARIO(
         "indices")
       {
         REQUIRE(index_range_collection.size() == 1);
-        REQUIRE(index_range_collection.getRangeCstRefAt(0).start ==
-                index_range_1.start - 1);
-        REQUIRE(index_range_collection.getRangeCstRefAt(0).stop ==
-                index_range_1.stop - 1);
+        REQUIRE(index_range_collection.getRangeCstRefAt(0).m_start ==
+                index_range_1.m_start);
+        REQUIRE(index_range_collection.getRangeCstRefAt(0).m_stop ==
+                index_range_1.m_stop);
       }
     }
 
     WHEN(
-      "That IndexRangeCollection is set with one string representative of three "
+      "That IndexRangeCollection is set with one string representative of a "
+      "single IndexRange instance of location type POSITION")
+    {
+      index_range_collection.setIndexRanges(index_range_string_1,
+                                            Enums::LocationType::POSITION);
+
+      THEN(
+        "The list must have size 1, and that object has to be the one set,  "
+        "with each first/second value decremented by one to convert positions "
+        "to "
+        "indices")
+      {
+        REQUIRE(index_range_collection.size() == 1);
+        REQUIRE(index_range_collection.getRangeCstRefAt(0).m_start ==
+                index_range_1.m_start - 1);
+        REQUIRE(index_range_collection.getRangeCstRefAt(0).m_stop ==
+                index_range_1.m_stop - 1);
+      }
+    }
+
+    WHEN(
+      "That IndexRangeCollection is set with one string representative of "
+      "three "
       "IndexRange instances")
     {
-      index_range_collection.setIndexRanges(all_three_index_range_strings);
+      index_range_collection.setIndexRanges(all_three_index_range_strings,
+                                            Enums::LocationType::INDEX);
 
       THEN("The list must have size 3")
       {
@@ -381,22 +421,22 @@ SCENARIO(
 
       AND_THEN("All the members of the list should have proper values")
       {
-        REQUIRE(index_range_collection.getRangeCstRefAt(0).start ==
-                index_range_1.start - 1);
-        REQUIRE(index_range_collection.getRangeCstRefAt(0).stop ==
-                index_range_1.stop - 1);
+        REQUIRE(index_range_collection.getRangeCstRefAt(0).m_start ==
+                index_range_1.m_start);
+        REQUIRE(index_range_collection.getRangeCstRefAt(0).m_stop ==
+                index_range_1.m_stop);
 
-        REQUIRE(index_range_collection.getRangeCstRefAt(1).start ==
-                index_range_2.start - 1);
-        REQUIRE(index_range_collection.getRangeCstRefAt(1).stop ==
-                index_range_2.stop - 1);
+        REQUIRE(index_range_collection.getRangeCstRefAt(1).m_start ==
+                index_range_2.m_start);
+        REQUIRE(index_range_collection.getRangeCstRefAt(1).m_stop ==
+                index_range_2.m_stop);
 
-        REQUIRE(
-          index_range_collection.getRangeCstRefAt(index_range_collection.size() - 1).start ==
-          index_range_3.start - 1);
-        REQUIRE(
-          index_range_collection.getRangeCstRefAt(index_range_collection.size() - 1).stop ==
-          index_range_3.stop - 1);
+        REQUIRE(index_range_collection
+                  .getRangeCstRefAt(index_range_collection.size() - 1)
+                  .m_start == index_range_3.m_start);
+        REQUIRE(index_range_collection
+                  .getRangeCstRefAt(index_range_collection.size() - 1)
+                  .m_stop == index_range_3.m_stop);
       }
     }
   }
@@ -411,28 +451,29 @@ SCENARIO("IndexRangeCollection instances can provide topological data",
 
     QString all_index_range_strings("[1-20]");
 
-    index_range_collection.setIndexRanges(all_index_range_strings);
+    index_range_collection.setIndexRanges(all_index_range_strings,
+                                          Enums::LocationType::POSITION);
 
     REQUIRE(index_range_collection.size() == 1);
 
-    std::vector<std::size_t> left_most_indices;
-    std::vector<std::size_t> right_most_indices;
+    QList<qsizetype> left_most_indices;
+    QList<qsizetype> right_most_indices;
 
     WHEN("Asking for the leftmost and the rightmost IndexRange instances")
     {
       left_most_indices = index_range_collection.indicesOfLeftMostIndexRanges();
-      right_most_indices = index_range_collection.indicesOfRightMostIndexRanges();
+      right_most_indices =
+        index_range_collection.indicesOfRightMostIndexRanges();
       REQUIRE(left_most_indices.size() == 1);
       REQUIRE(right_most_indices.size() == 1);
 
-      THEN(
-        "The indices should actually match the correct IndexRange instance")
+      THEN("The indices should actually match the correct IndexRange instance")
       {
+        REQUIRE(index_range_collection.getRangeCstRefAt(left_most_indices.at(0))
+                  .m_start == 0);
         REQUIRE(
-          index_range_collection.getRangeCstRefAt(left_most_indices.at(0)).start == 0);
-        REQUIRE(
-          index_range_collection.getRangeCstRefAt(right_most_indices.at(0)).stop ==
-          19);
+          index_range_collection.getRangeCstRefAt(right_most_indices.at(0))
+            .m_stop == 19);
       }
     }
 
@@ -467,34 +508,36 @@ SCENARIO("IndexRangeCollection instances can provide topological data",
   }
 
   GIVEN(
-    "A IndexRangeCollection instance with a number of non-overlapping IndexRange")
+    "A IndexRangeCollection instance with a number of non-overlapping "
+    "IndexRange")
   {
     IndexRangeCollection index_range_collection;
 
     QString all_index_range_strings("[1-20][25-45][55-100]");
 
-    index_range_collection.setIndexRanges(all_index_range_strings);
+    index_range_collection.setIndexRanges(all_index_range_strings,
+                                          Enums::LocationType::POSITION);
 
     REQUIRE(index_range_collection.size() == 3);
 
-    std::vector<std::size_t> left_most_indices;
-    std::vector<std::size_t> right_most_indices;
+    QList<qsizetype> left_most_indices;
+    QList<qsizetype> right_most_indices;
 
     WHEN("Asking for the leftmost and the rightmost IndexRangeCollection")
     {
       left_most_indices = index_range_collection.indicesOfLeftMostIndexRanges();
-      right_most_indices = index_range_collection.indicesOfRightMostIndexRanges();
+      right_most_indices =
+        index_range_collection.indicesOfRightMostIndexRanges();
       REQUIRE(left_most_indices.size() == 1);
       REQUIRE(right_most_indices.size() == 1);
 
-      THEN(
-        "The indices should actually match the right IndexRange instances")
+      THEN("The indices should actually match the right IndexRange instances")
       {
+        REQUIRE(index_range_collection.getRangeCstRefAt(left_most_indices.at(0))
+                  .m_start == 0);
         REQUIRE(
-          index_range_collection.getRangeCstRefAt(left_most_indices.at(0)).start == 0);
-        REQUIRE(
-          index_range_collection.getRangeCstRefAt(right_most_indices.at(0)).stop ==
-          99);
+          index_range_collection.getRangeCstRefAt(right_most_indices.at(0))
+            .m_stop == 99);
       }
     }
 
@@ -547,34 +590,35 @@ SCENARIO("IndexRangeCollection instances can provide topological data",
     QString all_index_range_strings(
       "[1-20][1-30][10-50][15-80][25-100][30-100]");
 
-    index_range_collection.setIndexRanges(all_index_range_strings);
+    index_range_collection.setIndexRanges(all_index_range_strings,
+                                          Enums::LocationType::POSITION);
 
     REQUIRE(index_range_collection.size() == 6);
 
-    std::vector<std::size_t> left_most_indices;
-    std::vector<std::size_t> right_most_indices;
+    QList<qsizetype> left_most_indices;
+    QList<qsizetype> right_most_indices;
 
     WHEN("Asking for the leftmost and the rightmost IndexRangeCollection")
     {
       left_most_indices = index_range_collection.indicesOfLeftMostIndexRanges();
-      right_most_indices = index_range_collection.indicesOfRightMostIndexRanges();
+      right_most_indices =
+        index_range_collection.indicesOfRightMostIndexRanges();
       REQUIRE(left_most_indices.size() == 2);
       REQUIRE(right_most_indices.size() == 2);
 
-      THEN(
-        "The indices should actually match the right IndexRange instances")
+      THEN("The indices should actually match the right IndexRange instances")
       {
+        REQUIRE(index_range_collection.getRangeCstRefAt(left_most_indices.at(0))
+                  .m_start == 0);
         REQUIRE(
-          index_range_collection.getRangeCstRefAt(left_most_indices.at(0)).start == 0);
+          index_range_collection.getRangeCstRefAt(left_most_indices.back())
+            .m_start == 0);
         REQUIRE(
-          index_range_collection.getRangeCstRefAt(left_most_indices.back()).start ==
-          0);
+          index_range_collection.getRangeCstRefAt(right_most_indices.at(0))
+            .m_stop == 99);
         REQUIRE(
-          index_range_collection.getRangeCstRefAt(right_most_indices.at(0)).stop ==
-          99);
-        REQUIRE(
-          index_range_collection.getRangeCstRefAt(right_most_indices.back()).stop ==
-          99);
+          index_range_collection.getRangeCstRefAt(right_most_indices.back())
+            .m_stop == 99);
       }
     }
 
@@ -642,7 +686,8 @@ SCENARIO("IndexRangeCollection instances can self-describe with text strings",
 
   GIVEN("Construction with a string describing three IndexRange instances")
   {
-    IndexRangeCollection index_range_collection(all_three_index_range_strings);
+    IndexRangeCollection index_range_collection(all_three_index_range_strings,
+                                                Enums::LocationType::POSITION);
 
     WHEN("When asked to self-describe as indices")
     {
@@ -680,12 +725,13 @@ SCENARIO("IndexRangeCollection and IndexRange instances can be compared",
   IndexRange index_range_3(30, 170);
 
   QString all_three_index_range_strings = QString("%1%2%3")
-                                               .arg(index_range_string_1)
-                                               .arg(index_range_string_2)
-                                               .arg(index_range_string_3);
+                                            .arg(index_range_string_1)
+                                            .arg(index_range_string_2)
+                                            .arg(index_range_string_3);
 
   GIVEN("A IndexRangeCollection instance with 3 IndexRange instances")
   {
+    // By default location type INDEX.
     IndexRangeCollection index_range_collection(all_three_index_range_strings);
 
     THEN("The list must have size 3")
@@ -695,47 +741,49 @@ SCENARIO("IndexRangeCollection and IndexRange instances can be compared",
 
     AND_THEN("All the members of the list should have proper values")
     {
-      REQUIRE(index_range_collection.getRangeCstRefAt(0).start ==
-              index_range_1.start - 1);
-      REQUIRE(index_range_collection.getRangeCstRefAt(0).stop ==
-              index_range_1.stop - 1);
+      REQUIRE(index_range_collection.getRangeCstRefAt(0).m_start ==
+              index_range_1.m_start);
+      REQUIRE(index_range_collection.getRangeCstRefAt(0).m_stop ==
+              index_range_1.m_stop);
 
-      REQUIRE(index_range_collection.getRangeCstRefAt(1).start ==
-              index_range_2.start - 1);
-      REQUIRE(index_range_collection.getRangeCstRefAt(1).stop ==
-              index_range_2.stop - 1);
+      REQUIRE(index_range_collection.getRangeCstRefAt(1).m_start ==
+              index_range_2.m_start);
+      REQUIRE(index_range_collection.getRangeCstRefAt(1).m_stop ==
+              index_range_2.m_stop);
 
-      REQUIRE(
-        index_range_collection.getRangeCstRefAt(index_range_collection.size() - 1).start ==
-        index_range_3.start - 1);
-      REQUIRE(
-        index_range_collection.getRangeCstRefAt(index_range_collection.size() - 1).stop ==
-        index_range_3.stop - 1);
+      REQUIRE(index_range_collection
+                .getRangeCstRefAt(index_range_collection.size() - 1)
+                .m_start == index_range_3.m_start);
+      REQUIRE(index_range_collection
+                .getRangeCstRefAt(index_range_collection.size() - 1)
+                .m_stop == index_range_3.m_stop);
     }
 
-    WHEN("A new IndexRangeCollection instance is created as a copy of the first one")
+    WHEN(
+      "A new IndexRangeCollection instance is created as a copy of the first "
+      "one")
     {
       IndexRangeCollection new_index_range_collection(index_range_collection);
 
       THEN("The new instance should be identical to the initial one")
       {
         REQUIRE(new_index_range_collection.size() == 3);
-        REQUIRE(new_index_range_collection.getRangeCstRefAt(0).start ==
-                index_range_1.start - 1);
-        REQUIRE(new_index_range_collection.getRangeCstRefAt(0).stop ==
-                index_range_1.stop - 1);
+        REQUIRE(new_index_range_collection.getRangeCstRefAt(0).m_start ==
+                index_range_1.m_start);
+        REQUIRE(new_index_range_collection.getRangeCstRefAt(0).m_stop ==
+                index_range_1.m_stop);
 
-        REQUIRE(new_index_range_collection.getRangeCstRefAt(1).start ==
-                index_range_2.start - 1);
-        REQUIRE(new_index_range_collection.getRangeCstRefAt(1).stop ==
-                index_range_2.stop - 1);
+        REQUIRE(new_index_range_collection.getRangeCstRefAt(1).m_start ==
+                index_range_2.m_start);
+        REQUIRE(new_index_range_collection.getRangeCstRefAt(1).m_stop ==
+                index_range_2.m_stop);
 
-        REQUIRE(
-          new_index_range_collection.getRangeCstRefAt(new_index_range_collection.size() - 1)
-            .start == index_range_3.start - 1);
-        REQUIRE(
-          new_index_range_collection.getRangeCstRefAt(new_index_range_collection.size() - 1)
-            .stop == index_range_3.stop - 1);
+        REQUIRE(new_index_range_collection
+                  .getRangeCstRefAt(new_index_range_collection.size() - 1)
+                  .m_start == index_range_3.m_start);
+        REQUIRE(new_index_range_collection
+                  .getRangeCstRefAt(new_index_range_collection.size() - 1)
+                  .m_stop == index_range_3.m_stop);
       }
 
       AND_THEN("The comparison operators should return identity")
@@ -753,26 +801,26 @@ SCENARIO("IndexRangeCollection and IndexRange instances can be compared",
         IndexRangeCollection new_index_range_collection(index_range_collection);
 
         IndexRange &index_range = new_index_range_collection.getRangeRefAt(1);
-        index_range.start = 50;
-        index_range.stop = 150;
+        index_range.m_start     = 50;
+        index_range.m_stop      = 150;
 
         THEN("The new instance should not be identical anymore")
         {
           REQUIRE(new_index_range_collection.size() == 3);
-          REQUIRE(new_index_range_collection.getRangeCstRefAt(0).start ==
-                  index_range_1.start - 1);
-          REQUIRE(new_index_range_collection.getRangeCstRefAt(0).stop ==
-                  index_range_1.stop - 1);
+          REQUIRE(new_index_range_collection.getRangeCstRefAt(0).m_start ==
+                  index_range_1.m_start);
+          REQUIRE(new_index_range_collection.getRangeCstRefAt(0).m_stop ==
+                  index_range_1.m_stop);
 
-          REQUIRE(new_index_range_collection.getRangeCstRefAt(1).start == 50);
-          REQUIRE(new_index_range_collection.getRangeCstRefAt(1).stop == 150);
+          REQUIRE(new_index_range_collection.getRangeCstRefAt(1).m_start == 50);
+          REQUIRE(new_index_range_collection.getRangeCstRefAt(1).m_stop == 150);
 
-          REQUIRE(
-            new_index_range_collection.getRangeCstRefAt(new_index_range_collection.size() - 1)
-              .start == index_range_3.start - 1);
-          REQUIRE(
-            new_index_range_collection.getRangeCstRefAt(new_index_range_collection.size() - 1)
-              .stop == index_range_3.stop - 1);
+          REQUIRE(new_index_range_collection
+                    .getRangeCstRefAt(new_index_range_collection.size() - 1)
+                    .m_start == index_range_3.m_start);
+          REQUIRE(new_index_range_collection
+                    .getRangeCstRefAt(new_index_range_collection.size() - 1)
+                    .m_stop == index_range_3.m_stop);
         }
 
         AND_THEN("The comparison operators should return identity")
