@@ -17,10 +17,10 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Isotope.hpp>
-#include <libXpertMass/IsotopicData.hpp>
-#include <libXpertMass/IsotopicDataLibraryHandler.hpp>
-#include <libXpertMass/IsotopicDataUserConfigHandler.hpp>
+#include "MsXpS/libXpertMassCore/Isotope.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicData.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicDataLibraryHandler.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicDataUserConfigHandler.hpp"
 
 /////////////////////// Local includes
 #include "tests-config.h"
