@@ -21,7 +21,7 @@
 /////////////////////// Local includes
 #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/Modif.hpp>
+#include "MsXpS/libXpertMassCore/Modif.hpp"
 
 namespace MsXpS
 {
