@@ -19,8 +19,7 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/Monomer.hpp>
-
+#include "MsXpS/libXpertMassCore/Monomer.hpp"
 
 namespace MsXpS
 {
@@ -62,7 +61,7 @@ SCENARIO(
 
         REQUIRE(monomer.isKnownByNameInPolChemDef() ==
                 Enums::PolChemDefEntityStatus::POL_CHEM_DEF_NOT_AVAILABLE);
-        REQUIRE_FALSE(monomer.validate(error_list_monomer));
+        REQUIRE_FALSE(monomer.validate(&error_list_monomer));
       }
 
       AND_WHEN("The PolChemDef is set")
@@ -77,7 +76,7 @@ SCENARIO(
           REQUIRE(monomer.isKnownByNameInPolChemDef() ==
                   Enums::PolChemDefEntityStatus::ENTITY_NOT_KNOWN);
 
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
 
         AND_WHEN("The name is set")
@@ -92,7 +91,7 @@ SCENARIO(
             REQUIRE(monomer.isKnownByNameInPolChemDef() ==
                     Enums::PolChemDefEntityStatus::ENTITY_KNOWN);
 
-            REQUIRE_FALSE(monomer.validate(error_list_monomer));
+            REQUIRE_FALSE(monomer.validate(&error_list_monomer));
           }
 
           AND_WHEN("The code is set")
@@ -111,7 +110,7 @@ SCENARIO(
               REQUIRE(monomer.isKnownByCodeInPolChemDef() ==
                       Enums::PolChemDefEntityStatus::ENTITY_KNOWN);
 
-              REQUIRE_FALSE(monomer.validate(error_list_monomer));
+              REQUIRE_FALSE(monomer.validate(&error_list_monomer));
             }
 
             AND_WHEN("The formula is set")
@@ -129,7 +128,7 @@ SCENARIO(
                 REQUIRE(monomer.isKnownByCodeInPolChemDef() ==
                         Enums::PolChemDefEntityStatus::ENTITY_KNOWN);
 
-                REQUIRE(monomer.validate(error_list_monomer));
+                REQUIRE(monomer.validate(&error_list_monomer));
               }
             }
           }
@@ -179,7 +178,7 @@ SCENARIO("Monomers can be constructed using a valid XML mnm element",
           "thoroughly validate successfully because of no PolChemDef")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -190,7 +189,7 @@ SCENARIO("Monomers can be constructed using a valid XML mnm element",
         THEN("The new Monomer instance is not valid and does not validate")
         {
           REQUIRE_FALSE(new_monomer.isValid());
-          REQUIRE_FALSE(new_monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(new_monomer.validate(&error_list_monomer));
         }
       }
 
@@ -202,7 +201,7 @@ SCENARIO("Monomers can be constructed using a valid XML mnm element",
         THEN("The new Monomer instance is not valid and does not validate")
         {
           REQUIRE_FALSE(new_monomer.isValid());
-          REQUIRE_FALSE(new_monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(new_monomer.validate(&error_list_monomer));
         }
       }
     }
@@ -220,7 +219,7 @@ SCENARIO("Monomers can be constructed using a valid XML mnm element",
         AND_THEN("The Monomer instance must validate successfully")
         {
           REQUIRE(monomer.isValid());
-          REQUIRE(monomer.validate(error_list_monomer));
+          REQUIRE(monomer.validate(&error_list_monomer));
         }
       }
     }
@@ -503,7 +502,7 @@ SCENARIO(
         REQUIRE(monomer.getFormula().toStdString() == "");
 
         REQUIRE_FALSE(monomer.isValid());
-        REQUIRE_FALSE(monomer.validate(error_list_monomer));
+        REQUIRE_FALSE(monomer.validate(&error_list_monomer));
 
         AND_WHEN(
           "The monomer instance is asked to render in itself the <monomer> XML "
@@ -522,7 +521,7 @@ SCENARIO(
 
             REQUIRE(monomer.isValid());
 
-            REQUIRE(monomer.validate(error_list_monomer));
+            REQUIRE(monomer.validate(&error_list_monomer));
 
             AND_THEN(
               "Calculating the Monomer masses should succeed (not accounting "
@@ -633,7 +632,7 @@ SCENARIO(
       THEN("The monomer should be valid and should validate successfully")
       {
         REQUIRE(monomer.isValid());
-        REQUIRE(monomer.validate(error_list_monomer));
+        REQUIRE(monomer.validate(&error_list_monomer));
       }
 
       AND_WHEN("An invalid code is set with setCode()")
@@ -645,7 +644,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -658,7 +657,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
     }
@@ -687,7 +686,7 @@ SCENARIO(
       THEN("The monomer should be valid and should validate successfully")
       {
         REQUIRE(monomer.isValid());
-        REQUIRE(monomer.validate(error_list_monomer));
+        REQUIRE(monomer.validate(&error_list_monomer));
       }
 
       AND_WHEN("An empty code is set with setCode()")
@@ -699,7 +698,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -710,7 +709,7 @@ SCENARIO(
         THEN("The monomer becomes valid and does validate successfully")
         {
           REQUIRE(monomer.isValid());
-          REQUIRE(monomer.validate(error_list_monomer));
+          REQUIRE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -722,7 +721,7 @@ SCENARIO(
         THEN("The monomer is still valid and does validate successfully")
         {
           REQUIRE(monomer.isValid());
-          REQUIRE(monomer.validate(error_list_monomer));
+          REQUIRE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -735,7 +734,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -748,7 +747,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -761,7 +760,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -774,7 +773,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -787,7 +786,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
 
@@ -800,7 +799,7 @@ SCENARIO(
           "anymore")
         {
           REQUIRE_FALSE(monomer.isValid());
-          REQUIRE_FALSE(monomer.validate(error_list_monomer));
+          REQUIRE_FALSE(monomer.validate(&error_list_monomer));
         }
       }
     }
@@ -840,7 +839,7 @@ SCENARIO(
 
       first_uuid = monomer.modify(methylation,
                                   /* override modif count */ false,
-                                  error_list_monomer);
+                                  &error_list_monomer);
 
       THEN("The modification should be successful")
       {
@@ -855,7 +854,7 @@ SCENARIO(
       {
         second_uuid = monomer.modify(methylation,
                                      /* override modif count */ false,
-                                     error_list_monomer);
+                                     &error_list_monomer);
 
         THEN("The modification should be successful")
         {
@@ -867,7 +866,7 @@ SCENARIO(
         {
           third_uuid = monomer.modify(methylation,
                                       /* override modif count */ false,
-                                      error_list_monomer);
+                                      &error_list_monomer);
 
           THEN("The modification should be successful")
           {
@@ -879,7 +878,7 @@ SCENARIO(
           {
             fourth_uuid = monomer.modify(methylation,
                                          /* override modif count */ false,
-                                         error_list_monomer);
+                                         &error_list_monomer);
 
             THEN("The modification should not be successful (> max count)")
             {
@@ -892,7 +891,7 @@ SCENARIO(
             {
               fourth_uuid = monomer.modify(methylation,
                                            /* override modif count */ true,
-                                           error_list_monomer);
+                                           &error_list_monomer);
 
               THEN(
                 "The modification should be successful (> max count "
@@ -971,7 +970,7 @@ SCENARIO(
     {
       QString uuid = monomer.modify(*oxidation_up.get(),
                                     /* override modif count */ false,
-                                    error_list_monomer);
+                                    &error_list_monomer);
 
       THEN("The monomer modification process should succeed")
       {
@@ -1056,7 +1055,7 @@ SCENARIO(
 
         REQUIRE(monomer_4.modify(*phosphorylation_up.get(),
                                  /* override modif count */ false,
-                                 error_list_monomer) != nullptr);
+                                 &error_list_monomer) != nullptr);
 
         AND_WHEN("The first monomer is assigned to the fourth monomer")
         {
@@ -1213,7 +1212,7 @@ SCENARIO(
 
     REQUIRE(monomer.modify(*oxidation_up.get(),
                            /* override modif count */ false,
-                           error_list_monomer) != nullptr);
+                           &error_list_monomer) != nullptr);
 
     THEN("That Monomer instance is identical to itself")
     {
@@ -1303,7 +1302,7 @@ SCENARIO(
 
         REQUIRE(monomer_2.modify(*oxidation_up.get(),
                                  /* override modif count */ false,
-                                 error_list_monomer) != nullptr);
+                                 &error_list_monomer) != nullptr);
 
         THEN("The second and the first monomers are no more equal")
         {
@@ -1332,7 +1331,7 @@ SCENARIO(
 
         REQUIRE(monomer_2.modify(*formylation_up.get(),
                                  /* override modif count */ false,
-                                 error_list_monomer) != nullptr);
+                                 &error_list_monomer) != nullptr);
 
         THEN("The second and the first monomers are no more equal")
         {
@@ -1346,7 +1345,6 @@ SCENARIO(
   }
 }
 
-
 SCENARIO("Monomer instances can be modified using Modif objects", "[Monomer]")
 {
   PolChemDefCstSPtr pol_chem_def_csp =
@@ -1371,7 +1369,7 @@ SCENARIO("Monomer instances can be modified using Modif objects", "[Monomer]")
       {
         QString uuid = monomer.modify(*oxidation_up.get(),
                                       /* override modif count */ false,
-                                      error_list_monomer);
+                                      &error_list_monomer);
 
         THEN("The monomer modification process should succeed")
         {
@@ -1395,7 +1393,7 @@ SCENARIO("Monomer instances can be modified using Modif objects", "[Monomer]")
         {
           QString uuid = monomer.modify(*oxidation_up.get(),
                                         /* override modif count */ false,
-                                        error_list_monomer);
+                                        &error_list_monomer);
 
           THEN("The monomer modification process should fail")
           {
@@ -1416,7 +1414,7 @@ SCENARIO("Monomer instances can be modified using Modif objects", "[Monomer]")
           {
             QString uuid = monomer.modify(*oxidation_up.get(),
                                           /* override modif count */ false,
-                                          error_list_monomer);
+                                          &error_list_monomer);
 
             THEN("The modification process should fail")
             {
@@ -1446,7 +1444,7 @@ SCENARIO("Monomer instances can be modified using Modif objects", "[Monomer]")
       {
         QString uuid = monomer.modify(modif,
                                       /* override modif count */ false,
-                                      error_list_monomer);
+                                      &error_list_monomer);
 
         THEN("The monomer modification process should succeed")
         {
@@ -1459,7 +1457,7 @@ SCENARIO("Monomer instances can be modified using Modif objects", "[Monomer]")
         {
           QString uuid = monomer.modify(modif,
                                         /* override modif count */ false,
-                                        error_list_monomer);
+                                        &error_list_monomer);
 
           THEN("The monomer modification process should fail")
           {
@@ -1480,7 +1478,7 @@ SCENARIO("Monomer instances can be modified using Modif objects", "[Monomer]")
           {
             QString uuid = monomer.modify(modif,
                                           /* override modif count */ false,
-                                          error_list_monomer);
+                                          &error_list_monomer);
 
             THEN("The modification process should fail")
             {
@@ -1517,10 +1515,11 @@ SCENARIO("A Monomer that is modified with a Modif has its masses that change",
     {
       QString uuid = monomer.modify(*oxidation_up.get(),
                                     /* override modif count */ false,
-                                    error_list_monomer);
+                                    &error_list_monomer);
       REQUIRE_FALSE(uuid.isEmpty());
       REQUIRE(monomer.getModifsCstRef().size() == 1);
-      REQUIRE(monomer.calculateMasses(nullptr, Enums::ChemicalEntity::MODIF) == true);
+      REQUIRE(monomer.calculateMasses(nullptr, Enums::ChemicalEntity::MODIF) ==
+              true);
 
       THEN("The masses of the Monomer do change")
       {
@@ -1541,7 +1540,7 @@ SCENARIO("A Monomer that is modified with a Modif has its masses that change",
 
       THEN("The monomer should validate the modification also")
       {
-        REQUIRE(monomer.validate(error_list_monomer));
+        REQUIRE(monomer.validate(&error_list_monomer));
       }
 
       AND_WHEN("The monomer is unmodified and the masses are recalculated")
@@ -1575,7 +1574,6 @@ SCENARIO("A Monomer that is modified with a Modif has its masses that change",
   }
 }
 
-
 SCENARIO("A Monomer cannot be correctly modified with an invalid Modif",
          "[Monomer]")
 {
@@ -1588,7 +1586,7 @@ SCENARIO("A Monomer cannot be correctly modified with an invalid Modif",
   {
     Monomer monomer(pol_chem_def_csp, "Tryptophan", "W", "C11H10N2O1");
 
-    REQUIRE(monomer.validate(error_list_monomer));
+    REQUIRE(monomer.validate(&error_list_monomer));
     REQUIRE(monomer.isValid());
 
     std::unique_ptr<Modif> fake_oxidation_up =
@@ -1605,7 +1603,7 @@ SCENARIO("A Monomer cannot be correctly modified with an invalid Modif",
     {
       QString uuid = monomer.modify(*fake_oxidation_up.get(),
                                     /* override modif count */ false,
-                                    error_list_monomer);
+                                    &error_list_monomer);
 
       REQUIRE_FALSE(uuid.isEmpty());
       REQUIRE(monomer.getModifsCstRef().size() == 1);
@@ -1632,7 +1630,7 @@ SCENARIO("A Monomer cannot be correctly modified with an invalid Modif",
 
       THEN("The monomer modified with an incorrect formula should not validate")
       {
-        REQUIRE_FALSE(monomer.validate(error_list_monomer));
+        REQUIRE_FALSE(monomer.validate(&error_list_monomer));
       }
 
       AND_WHEN("The monomer is unmodified and the masses a recalculated")
@@ -1666,7 +1664,7 @@ SCENARIO("A Monomer cannot be correctly modified with an invalid Modif",
           "The monomer should validate, since it is no more modified with an "
           "incorrect formula")
         {
-          REQUIRE(monomer.validate(error_list_monomer));
+          REQUIRE(monomer.validate(&error_list_monomer));
           REQUIRE(monomer.isValid());
         }
       }
@@ -1687,21 +1685,22 @@ SCENARIO(
     Monomer monomer =
       Monomer(pol_chem_def_csp, "Tryptophan", "W", "C11H10N2O1");
 
-    REQUIRE(monomer.validate(error_list_monomer));
+    REQUIRE(monomer.validate(&error_list_monomer));
     REQUIRE(monomer.isValid());
 
     WHEN("Asked to compute masses and the elemental composition formula")
     {
       REQUIRE(monomer.calculateMasses(nullptr));
 
-      QString elem_composition = monomer.calculateFormula(Enums::ChemicalEntity::NONE);
+      QString elem_composition =
+        monomer.calculateFormula(Enums::ChemicalEntity::NONE);
 
       // qDebug() <<  "The elemental composition:" <<  elem_composition;
 
       Formula the_formula(elem_composition);
       REQUIRE_FALSE(the_formula.isValid());
       REQUIRE(the_formula.validate(pol_chem_def_csp->getIsotopicDataCstSPtr(),
-                                   error_list_monomer));
+                                   &error_list_monomer));
       REQUIRE(the_formula.isValid());
       REQUIRE(the_formula.getActionFormula().toStdString() == "C11H10N2O1");
 
@@ -1759,7 +1758,7 @@ SCENARIO(
       {
         QString uuid = monomer.modify(*oxidation_up.get(),
                                       /* override modif count */ false,
-                                      error_list_monomer);
+                                      &error_list_monomer);
         REQUIRE_FALSE(uuid.isEmpty());
         REQUIRE(*monomer.getModifForUuid(uuid) == *oxidation_up.get());
 
@@ -1769,7 +1768,8 @@ SCENARIO(
         }
         AND_WHEN("The new masses are calculated")
         {
-          REQUIRE(monomer.calculateMasses(nullptr, Enums::ChemicalEntity::MODIF));
+          REQUIRE(
+            monomer.calculateMasses(nullptr, Enums::ChemicalEntity::MODIF));
 
           THEN("These masses are reported correctly")
           {
@@ -1806,7 +1806,7 @@ SCENARIO(
             the_formula.validate(pol_chem_def_csp->getIsotopicDataCstSPtr(),
                                  /*store*/ true,
                                  /*reset*/ false,
-                                 error_list_monomer));
+                                 &error_list_monomer));
           REQUIRE(the_formula.isValid());
 
           THEN(
@@ -1836,7 +1836,7 @@ SCENARIO(
             the_formula.validate(pol_chem_def_csp->getIsotopicDataCstSPtr(),
                                  /*store*/ true,
                                  /*reset*/ false,
-                                 error_list_monomer));
+                                 &error_list_monomer));
           REQUIRE(the_formula.isValid());
 
           THEN(
@@ -1866,7 +1866,7 @@ SCENARIO(
             REQUIRE_FALSE(
               Formula(elem_composition)
                 .validate(pol_chem_def_csp->getIsotopicDataCstSPtr(),
-                          error_list_monomer));
+                          &error_list_monomer));
           }
         }
       }
